# encoding: utf-8
# module System.Net.WebSockets calls itself WebSockets
# from System,Version=4.0.0.0,Culture=neutral,PublicKeyToken=b77a5c561934e089
# by generator 1.145
""" NamespaceTracker represent a CLS namespace. """
# no imports

# no functions
# classes

class WebSocket(object,IDisposable):
 # no doc
 def Abort(self):
  """ Abort(self: WebSocket) """
  pass
 def CloseAsync(self,closeStatus,statusDescription,cancellationToken):
  """ CloseAsync(self: WebSocket,closeStatus: WebSocketCloseStatus,statusDescription: str,cancellationToken: CancellationToken) -> Task """
  pass
 def CloseOutputAsync(self,closeStatus,statusDescription,cancellationToken):
  """ CloseOutputAsync(self: WebSocket,closeStatus: WebSocketCloseStatus,statusDescription: str,cancellationToken: CancellationToken) -> Task """
  pass
 @staticmethod
 def CreateClientBuffer(receiveBufferSize,sendBufferSize):
  """ CreateClientBuffer(receiveBufferSize: int,sendBufferSize: int) -> ArraySegment[Byte] """
  pass
 @staticmethod
 def CreateClientWebSocket(innerStream,subProtocol,receiveBufferSize,sendBufferSize,keepAliveInterval,useZeroMaskingKey,internalBuffer):
  """ CreateClientWebSocket(innerStream: Stream,subProtocol: str,receiveBufferSize: int,sendBufferSize: int,keepAliveInterval: TimeSpan,useZeroMaskingKey: bool,internalBuffer: ArraySegment[Byte]) -> WebSocket """
  pass
 @staticmethod
 def CreateServerBuffer(receiveBufferSize):
  """ CreateServerBuffer(receiveBufferSize: int) -> ArraySegment[Byte] """
  pass
 def Dispose(self):
  """ Dispose(self: WebSocket) """
  pass
 @staticmethod
 def IsApplicationTargeting45():
  """ IsApplicationTargeting45() -> bool """
  pass
 def IsStateTerminal(self,*args):
  """ IsStateTerminal(state: WebSocketState) -> bool """
  pass
 def ReceiveAsync(self,buffer,cancellationToken):
  """ ReceiveAsync(self: WebSocket,buffer: ArraySegment[Byte],cancellationToken: CancellationToken) -> Task[WebSocketReceiveResult] """
  pass
 @staticmethod
 def RegisterPrefixes():
  """ RegisterPrefixes() """
  pass
 def SendAsync(self,buffer,messageType,endOfMessage,cancellationToken):
  """ SendAsync(self: WebSocket,buffer: ArraySegment[Byte],messageType: WebSocketMessageType,endOfMessage: bool,cancellationToken: CancellationToken) -> Task """
  pass
 def ThrowOnInvalidState(self,*args):
  """ ThrowOnInvalidState(state: WebSocketState,*validStates: Array[WebSocketState]) """
  pass
 def __enter__(self,*args):
  """
  __enter__(self: IDisposable) -> object

  

   Provides the implementation of __enter__ for objects which implement IDisposable.
  """
  pass
 def __exit__(self,*args):
  """
  __exit__(self: IDisposable,exc_type: object,exc_value: object,exc_back: object)

   Provides the implementation of __exit__ for objects which implement IDisposable.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass
 CloseStatus=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: CloseStatus(self: WebSocket) -> Nullable[WebSocketCloseStatus]



"""

 CloseStatusDescription=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: CloseStatusDescription(self: WebSocket) -> str



"""

 State=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: State(self: WebSocket) -> WebSocketState



"""

 SubProtocol=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: SubProtocol(self: WebSocket) -> str



"""


 DefaultKeepAliveInterval=None


class ClientWebSocket(WebSocket,IDisposable):
 """ ClientWebSocket() """
 def Abort(self):
  """ Abort(self: ClientWebSocket) """
  pass
 def CloseAsync(self,closeStatus,statusDescription,cancellationToken):
  """ CloseAsync(self: ClientWebSocket,closeStatus: WebSocketCloseStatus,statusDescription: str,cancellationToken: CancellationToken) -> Task """
  pass
 def CloseOutputAsync(self,closeStatus,statusDescription,cancellationToken):
  """ CloseOutputAsync(self: ClientWebSocket,closeStatus: WebSocketCloseStatus,statusDescription: str,cancellationToken: CancellationToken) -> Task """
  pass
 def ConnectAsync(self,uri,cancellationToken):
  """ ConnectAsync(self: ClientWebSocket,uri: Uri,cancellationToken: CancellationToken) -> Task """
  pass
 def Dispose(self):
  """ Dispose(self: ClientWebSocket) """
  pass
 def ReceiveAsync(self,buffer,cancellationToken):
  """ ReceiveAsync(self: ClientWebSocket,buffer: ArraySegment[Byte],cancellationToken: CancellationToken) -> Task[WebSocketReceiveResult] """
  pass
 def SendAsync(self,buffer,messageType,endOfMessage,cancellationToken):
  """ SendAsync(self: ClientWebSocket,buffer: ArraySegment[Byte],messageType: WebSocketMessageType,endOfMessage: bool,cancellationToken: CancellationToken) -> Task """
  pass
 def __enter__(self,*args):
  """
  __enter__(self: IDisposable) -> object

  

   Provides the implementation of __enter__ for objects which implement IDisposable.
  """
  pass
 def __exit__(self,*args):
  """
  __exit__(self: IDisposable,exc_type: object,exc_value: object,exc_back: object)

   Provides the implementation of __exit__ for objects which implement IDisposable.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 CloseStatus=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: CloseStatus(self: ClientWebSocket) -> Nullable[WebSocketCloseStatus]



"""

 CloseStatusDescription=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: CloseStatusDescription(self: ClientWebSocket) -> str



"""

 Options=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: Options(self: ClientWebSocket) -> ClientWebSocketOptions



"""

 State=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: State(self: ClientWebSocket) -> WebSocketState



"""

 SubProtocol=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: SubProtocol(self: ClientWebSocket) -> str



"""



class ClientWebSocketOptions(object):
 # no doc
 def AddSubProtocol(self,subProtocol):
  """ AddSubProtocol(self: ClientWebSocketOptions,subProtocol: str) """
  pass
 def SetBuffer(self,receiveBufferSize,sendBufferSize,buffer=None):
  """ SetBuffer(self: ClientWebSocketOptions,receiveBufferSize: int,sendBufferSize: int,buffer: ArraySegment[Byte])SetBuffer(self: ClientWebSocketOptions,receiveBufferSize: int,sendBufferSize: int) """
  pass
 def SetRequestHeader(self,headerName,headerValue):
  """ SetRequestHeader(self: ClientWebSocketOptions,headerName: str,headerValue: str) """
  pass
 ClientCertificates=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: ClientCertificates(self: ClientWebSocketOptions) -> X509CertificateCollection



Set: ClientCertificates(self: ClientWebSocketOptions)=value

"""

 Cookies=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: Cookies(self: ClientWebSocketOptions) -> CookieContainer



Set: Cookies(self: ClientWebSocketOptions)=value

"""

 Credentials=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: Credentials(self: ClientWebSocketOptions) -> ICredentials



Set: Credentials(self: ClientWebSocketOptions)=value

"""

 KeepAliveInterval=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: KeepAliveInterval(self: ClientWebSocketOptions) -> TimeSpan



Set: KeepAliveInterval(self: ClientWebSocketOptions)=value

"""

 Proxy=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: Proxy(self: ClientWebSocketOptions) -> IWebProxy



Set: Proxy(self: ClientWebSocketOptions)=value

"""

 UseDefaultCredentials=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: UseDefaultCredentials(self: ClientWebSocketOptions) -> bool



Set: UseDefaultCredentials(self: ClientWebSocketOptions)=value

"""



class WebSocketContext(object):
 # no doc
 CookieCollection=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: CookieCollection(self: WebSocketContext) -> CookieCollection



"""

 Headers=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: Headers(self: WebSocketContext) -> NameValueCollection



"""

 IsAuthenticated=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: IsAuthenticated(self: WebSocketContext) -> bool



"""

 IsLocal=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: IsLocal(self: WebSocketContext) -> bool



"""

 IsSecureConnection=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: IsSecureConnection(self: WebSocketContext) -> bool



"""

 Origin=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: Origin(self: WebSocketContext) -> str



"""

 RequestUri=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: RequestUri(self: WebSocketContext) -> Uri



"""

 SecWebSocketKey=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: SecWebSocketKey(self: WebSocketContext) -> str



"""

 SecWebSocketProtocols=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: SecWebSocketProtocols(self: WebSocketContext) -> IEnumerable[str]



"""

 SecWebSocketVersion=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: SecWebSocketVersion(self: WebSocketContext) -> str



"""

 User=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: User(self: WebSocketContext) -> IPrincipal



"""

 WebSocket=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: WebSocket(self: WebSocketContext) -> WebSocket



"""



class HttpListenerWebSocketContext(WebSocketContext):
 # no doc
 CookieCollection=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: CookieCollection(self: HttpListenerWebSocketContext) -> CookieCollection



"""

 Headers=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: Headers(self: HttpListenerWebSocketContext) -> NameValueCollection



"""

 IsAuthenticated=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: IsAuthenticated(self: HttpListenerWebSocketContext) -> bool



"""

 IsLocal=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: IsLocal(self: HttpListenerWebSocketContext) -> bool



"""

 IsSecureConnection=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: IsSecureConnection(self: HttpListenerWebSocketContext) -> bool



"""

 Origin=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: Origin(self: HttpListenerWebSocketContext) -> str



"""

 RequestUri=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: RequestUri(self: HttpListenerWebSocketContext) -> Uri



"""

 SecWebSocketKey=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: SecWebSocketKey(self: HttpListenerWebSocketContext) -> str



"""

 SecWebSocketProtocols=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: SecWebSocketProtocols(self: HttpListenerWebSocketContext) -> IEnumerable[str]



"""

 SecWebSocketVersion=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: SecWebSocketVersion(self: HttpListenerWebSocketContext) -> str



"""

 User=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: User(self: HttpListenerWebSocketContext) -> IPrincipal



"""

 WebSocket=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: WebSocket(self: HttpListenerWebSocketContext) -> WebSocket



"""



class WebSocketCloseStatus(Enum,IComparable,IFormattable,IConvertible):
 """ enum WebSocketCloseStatus,values: Empty (1005),EndpointUnavailable (1001),InternalServerError (1011),InvalidMessageType (1003),InvalidPayloadData (1007),MandatoryExtension (1010),MessageTooBig (1009),NormalClosure (1000),PolicyViolation (1008),ProtocolError (1002) """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Empty=None
 EndpointUnavailable=None
 InternalServerError=None
 InvalidMessageType=None
 InvalidPayloadData=None
 MandatoryExtension=None
 MessageTooBig=None
 NormalClosure=None
 PolicyViolation=None
 ProtocolError=None
 value__=None


class WebSocketError(Enum,IComparable,IFormattable,IConvertible):
 """ enum WebSocketError,values: ConnectionClosedPrematurely (8),Faulted (2),HeaderError (7),InvalidMessageType (1),InvalidState (9),NativeError (3),NotAWebSocket (4),Success (0),UnsupportedProtocol (6),UnsupportedVersion (5) """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 ConnectionClosedPrematurely=None
 Faulted=None
 HeaderError=None
 InvalidMessageType=None
 InvalidState=None
 NativeError=None
 NotAWebSocket=None
 Success=None
 UnsupportedProtocol=None
 UnsupportedVersion=None
 value__=None


class WebSocketException(Win32Exception,ISerializable,_Exception):
 """
 WebSocketException()

 WebSocketException(error: WebSocketError)

 WebSocketException(error: WebSocketError,message: str)

 WebSocketException(error: WebSocketError,innerException: Exception)

 WebSocketException(error: WebSocketError,message: str,innerException: Exception)

 WebSocketException(nativeError: int)

 WebSocketException(nativeError: int,message: str)

 WebSocketException(nativeError: int,innerException: Exception)

 WebSocketException(error: WebSocketError,nativeError: int)

 WebSocketException(error: WebSocketError,nativeError: int,message: str)

 WebSocketException(error: WebSocketError,nativeError: int,innerException: Exception)

 WebSocketException(error: WebSocketError,nativeError: int,message: str,innerException: Exception)

 WebSocketException(message: str)

 WebSocketException(message: str,innerException: Exception)
 """
 def add_SerializeObjectState(self,*args):
  """ add_SerializeObjectState(self: Exception,value: EventHandler[SafeSerializationEventArgs]) """
  pass
 def GetObjectData(self,info,context):
  """ GetObjectData(self: WebSocketException,info: SerializationInfo,context: StreamingContext) """
  pass
 def remove_SerializeObjectState(self,*args):
  """ remove_SerializeObjectState(self: Exception,value: EventHandler[SafeSerializationEventArgs]) """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type)

  __new__(cls: type,error: WebSocketError)

  __new__(cls: type,error: WebSocketError,message: str)

  __new__(cls: type,error: WebSocketError,innerException: Exception)

  __new__(cls: type,error: WebSocketError,message: str,innerException: Exception)

  __new__(cls: type,nativeError: int)

  __new__(cls: type,nativeError: int,message: str)

  __new__(cls: type,nativeError: int,innerException: Exception)

  __new__(cls: type,error: WebSocketError,nativeError: int)

  __new__(cls: type,error: WebSocketError,nativeError: int,message: str)

  __new__(cls: type,error: WebSocketError,nativeError: int,innerException: Exception)

  __new__(cls: type,error: WebSocketError,nativeError: int,message: str,innerException: Exception)

  __new__(cls: type,message: str)

  __new__(cls: type,message: str,innerException: Exception)
  """
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 ErrorCode=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: ErrorCode(self: WebSocketException) -> int



"""

 WebSocketErrorCode=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: WebSocketErrorCode(self: WebSocketException) -> WebSocketError



"""



class WebSocketMessageType(Enum,IComparable,IFormattable,IConvertible):
 """ enum WebSocketMessageType,values: Binary (1),Close (2),Text (0) """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Binary=None
 Close=None
 Text=None
 value__=None


class WebSocketReceiveResult(object):
 """
 WebSocketReceiveResult(count: int,messageType: WebSocketMessageType,endOfMessage: bool)

 WebSocketReceiveResult(count: int,messageType: WebSocketMessageType,endOfMessage: bool,closeStatus: Nullable[WebSocketCloseStatus],closeStatusDescription: str)
 """
 @staticmethod
 def __new__(self,count,messageType,endOfMessage,closeStatus=None,closeStatusDescription=None):
  """
  __new__(cls: type,count: int,messageType: WebSocketMessageType,endOfMessage: bool)

  __new__(cls: type,count: int,messageType: WebSocketMessageType,endOfMessage: bool,closeStatus: Nullable[WebSocketCloseStatus],closeStatusDescription: str)
  """
  pass
 CloseStatus=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: CloseStatus(self: WebSocketReceiveResult) -> Nullable[WebSocketCloseStatus]



"""

 CloseStatusDescription=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: CloseStatusDescription(self: WebSocketReceiveResult) -> str



"""

 Count=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: Count(self: WebSocketReceiveResult) -> int



"""

 EndOfMessage=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: EndOfMessage(self: WebSocketReceiveResult) -> bool



"""

 MessageType=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: MessageType(self: WebSocketReceiveResult) -> WebSocketMessageType



"""



class WebSocketState(Enum,IComparable,IFormattable,IConvertible):
 """ enum WebSocketState,values: Aborted (6),Closed (5),CloseReceived (4),CloseSent (3),Connecting (1),None (0),Open (2) """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Aborted=None
 Closed=None
 CloseReceived=None
 CloseSent=None
 Connecting=None
 None=None
 Open=None
 value__=None





class ListChangedType(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies how the list changed.

 

 enum ListChangedType,values: ItemAdded (1),ItemChanged (4),ItemDeleted (2),ItemMoved (3),PropertyDescriptorAdded (5),PropertyDescriptorChanged (7),PropertyDescriptorDeleted (6),Reset (0)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 ItemAdded=None
 ItemChanged=None
 ItemDeleted=None
 ItemMoved=None
 PropertyDescriptorAdded=None
 PropertyDescriptorChanged=None
 PropertyDescriptorDeleted=None
 Reset=None
 value__=None




class SelectionRangeConverter(TypeConverter):
 """
 Provides a type converter to convert System.Windows.Forms.SelectionRange objects to and from various other types.

 

 SelectionRangeConverter()
 """
 def CanConvertFrom(self,*__args):
  """
  CanConvertFrom(self: SelectionRangeConverter,context: ITypeDescriptorContext,sourceType: Type) -> bool

  

   Determines if this converter can convert an object of the specified source type to the native 

    type of the converter by querying the supplied type descriptor context.

  

  

   context: A System.ComponentModel.ITypeDescriptorContext that provides a format context.

   sourceType: The source System.Type to be converted.

   Returns: true if the converter can perform the specified conversion; otherwise,false.
  """
  pass
 def CanConvertTo(self,*__args):
  """
  CanConvertTo(self: SelectionRangeConverter,context: ITypeDescriptorContext,destinationType: Type) -> bool

  

   Gets a value indicating whether this converter can convert an object to the specified 

    destination type by using the specified context.

  

  

   context: A System.ComponentModel.ITypeDescriptorContext that provides a format context.

   destinationType: The destination System.Type to convert into.

   Returns: true if this converter can perform the specified conversion; otherwise,false.
  """
  pass
 def ConvertFrom(self,*__args):
  """
  ConvertFrom(self: SelectionRangeConverter,context: ITypeDescriptorContext,culture: CultureInfo,value: object) -> object

  

   Converts the specified value to the converter's native type by using the specified locale.

  

   context: A System.ComponentModel.ITypeDescriptorContext that provides a format context.

   culture: The locale information for the conversion.

   value: The System.Object to convert.

   Returns: An System.Object that represents the converted value.
  """
  pass
 def ConvertTo(self,*__args):
  """
  ConvertTo(self: SelectionRangeConverter,context: ITypeDescriptorContext,culture: CultureInfo,value: object,destinationType: Type) -> object

  

   Converts the specified System.Windows.Forms.SelectionRangeConverter object to another type by 

    using the specified culture.

  

  

   context: A System.ComponentModel.ITypeDescriptorContext that provides a format context.

   culture: The locale information for the conversion.

   value: The System.Object to convert.

   destinationType: The destination System.Type to convert into.

   Returns: An System.Object that represents the converted value.
  """
  pass
 def CreateInstance(self,*__args):
  """
  CreateInstance(self: SelectionRangeConverter,context: ITypeDescriptorContext,propertyValues: IDictionary) -> object

  

   Creates a System.Windows.Forms.SelectionRange object by using the specified type descriptor and 

    set of property values for that object.

  

  

   context: A System.ComponentModel.ITypeDescriptorContext that provides a format context.

   propertyValues: An System.Collections.IDictionary that contains the new property values.

   Returns: If successful,the newly created System.Windows.Forms.SelectionRange; otherwise,this method 

    throws an exception.
  """
  pass
 def GetCreateInstanceSupported(self,context=None):
  """
  GetCreateInstanceSupported(self: SelectionRangeConverter,context: ITypeDescriptorContext) -> bool

  

   Determines if changing a value on an instance should require a call to 

    erload:System.Windows.Forms.SelectionRangeConverter.CreateInstance to create a new value.

  

  

   context: A System.ComponentModel.ITypeDescriptorContext that provides a format context.

   Returns: true if erload:System.Windows.Forms.SelectionRangeConverter.CreateInstance must be called to 

    make a change to one or more properties; otherwise false.
  """
  pass
 def GetProperties(self,*__args):
  """
  GetProperties(self: SelectionRangeConverter,context: ITypeDescriptorContext,value: object,attributes: Array[Attribute]) -> PropertyDescriptorCollection

  

   Returns the set of filtered properties for the System.Windows.Forms.SelectionRange type

  

   context: A System.ComponentModel.ITypeDescriptorContext that provides a format context.

   value: An System.Object that specifies the type of array for which to get properties.

   attributes: An array of type System.Attribute that is used as a filter.

   Returns: If successful,the set of properties that should be exposed for the 

    System.Windows.Forms.SelectionRange type; otherwise,null.
  """
  pass
 def GetPropertiesSupported(self,context=None):
  """
  GetPropertiesSupported(self: SelectionRangeConverter,context: ITypeDescriptorContext) -> bool

  

   Determines whether the current object supports properties that use the specified type descriptor 

    context.

  

  

   context: A System.ComponentModel.ITypeDescriptorContext that provides a format context.

   Returns: true if erload:System.Windows.Forms.SelectionRangeConverter.GetProperties can be called to find 

    the properties of a System.Windows.Forms.SelectionRange object; otherwise,false.
  """
  pass



# this entry is added to a journal when Revit stops the execution
# in journal mode. Checking for this string will help in determining if
# Revit has stopped the journal execution.
MODAL_OPEN = '0:< ADialog::doModal start'



class DataGridViewRowDividerDoubleClickEventArgs(HandledMouseEventArgs):
 """
 Provides data for the System.Windows.Forms.DataGridView.RowDividerDoubleClick event of a System.Windows.Forms.DataGridView.

 

 DataGridViewRowDividerDoubleClickEventArgs(rowIndex: int,e: HandledMouseEventArgs)
 """
 @staticmethod
 def __new__(self,rowIndex,e):
  """ __new__(cls: type,rowIndex: int,e: HandledMouseEventArgs) """
  pass
 RowIndex=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """The index of the row above the row divider that was double-clicked.



Get: RowIndex(self: DataGridViewRowDividerDoubleClickEventArgs) -> int



"""





class MulticastNotSupportedException(SystemException,ISerializable,_Exception):
 """
 The exception that is thrown when there is an attempt to combine two delegates based on the System.Delegate type instead of the System.MulticastDelegate type. This class cannot be inherited.

 

 MulticastNotSupportedException()

 MulticastNotSupportedException(message: str)

 MulticastNotSupportedException(message: str,inner: Exception)
 """
 def add_SerializeObjectState(self,*args):
  """ add_SerializeObjectState(self: Exception,value: EventHandler[SafeSerializationEventArgs]) """
  pass
 def remove_SerializeObjectState(self,*args):
  """ remove_SerializeObjectState(self: Exception,value: EventHandler[SafeSerializationEventArgs]) """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,message=None,inner=None):
  """
  __new__(cls: type)

  __new__(cls: type,message: str)

  __new__(cls: type,message: str,inner: Exception)
  """
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass



# encoding: utf-8
# module System.Windows.Shapes calls itself Shapes
# from PresentationFramework,Version=4.0.0.0,Culture=neutral,PublicKeyToken=31bf3856ad364e35
# by generator 1.145
""" NamespaceTracker represent a CLS namespace. """
# no imports

# no functions
# classes
from Shapes_parts.Shape import Shape
from Shapes_parts.Ellipse import Ellipse
from Shapes_parts.Line import Line
from Shapes_parts.Path import Path
from Shapes_parts.Polygon import Polygon
from Shapes_parts.Polyline import Polyline
from Shapes_parts.Rectangle import Rectangle



"""
The forms module provide several pre-build forms as well as a framework
from which you can build your own forms.

All classes documented in this section can be imported as such:

>>> from rpw.ui.forms import Console

"""

# FlexForm + Componets
from rpw.ui.forms.flexform import FlexForm
from rpw.ui.forms.flexform import Label, TextBox, Button, ComboBox, CheckBox
from rpw.ui.forms.flexform import Separator

# Pre-built, easy to use FlexForms
from rpw.ui.forms.quickform import SelectFromList, TextInput

# Out-of-the Box TaskDialogs
from rpw.ui.forms.taskdialog import Alert, TaskDialog, CommandLink

# RPW Interactive Console
from rpw.ui.forms.console import Console

# Out-of-the Box TaskDialogs
from rpw.ui.forms.os_dialog import select_file, select_folder



class PasswordPropertyTextAttribute(Attribute,_Attribute):
 """
 Indicates that an object's text representation is obscured by characters such as asterisks. This class cannot be inherited.

 

 PasswordPropertyTextAttribute()

 PasswordPropertyTextAttribute(password: bool)
 """
 def Equals(self,o):
  """
  Equals(self: PasswordPropertyTextAttribute,o: object) -> bool

  

   Determines whether two System.ComponentModel.PasswordPropertyTextAttribute instances are equal.

  

   o: The System.ComponentModel.PasswordPropertyTextAttribute to compare with the current 

    System.ComponentModel.PasswordPropertyTextAttribute.

  

   Returns: true if the specified System.ComponentModel.PasswordPropertyTextAttribute is equal to the 

    current System.ComponentModel.PasswordPropertyTextAttribute; otherwise,false.
  """
  pass
 def GetHashCode(self):
  """
  GetHashCode(self: PasswordPropertyTextAttribute) -> int

  

   Returns the hash code for this instance.

   Returns: A hash code for the current System.ComponentModel.PasswordPropertyTextAttribute.
  """
  pass
 def IsDefaultAttribute(self):
  """
  IsDefaultAttribute(self: PasswordPropertyTextAttribute) -> bool

  

   Returns an indication whether the value of this instance is the default value.

   Returns: true if this instance is the default attribute for the class; otherwise,false.
  """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==y """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,password=None):
  """
  __new__(cls: type)

  __new__(cls: type,password: bool)
  """
  pass
 def __ne__(self,*args):
  pass
 Password=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating if the property for which the System.ComponentModel.PasswordPropertyTextAttribute is defined should be shown as password text.



Get: Password(self: PasswordPropertyTextAttribute) -> bool



"""


 Default=None
 No=None
 Yes=None




class ImageListStreamer(object,ISerializable,IDisposable):
 """ Provides the data portion of an System.Windows.Forms.ImageList. """
 def Dispose(self):
  """
  Dispose(self: ImageListStreamer)

   Releases all resources used by the current instance of the 

    System.Windows.Forms.ImageListStreamer class.
  """
  pass
 def GetObjectData(self,si,context):
  """
  GetObjectData(self: ImageListStreamer,si: SerializationInfo,context: StreamingContext)

   Populates a System.Runtime.Serialization.SerializationInfo with the data needed to serialize the 

    target object.

  

  

   si: The System.Runtime.Serialization.SerializationInfo to populate with data.

   context: The System.Runtime.Serialization.StreamingContext that is the destination for this serialization.
  """
  pass
 def __enter__(self,*args):
  """
  __enter__(self: IDisposable) -> object

  

   Provides the implementation of __enter__ for objects which implement IDisposable.
  """
  pass
 def __exit__(self,*args):
  """
  __exit__(self: IDisposable,exc_type: object,exc_value: object,exc_back: object)

   Provides the implementation of __exit__ for objects which implement IDisposable.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __reduce_ex__(self,*args):
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass



class RuntimeMethodHandle(object,ISerializable):
 """ System.RuntimeMethodHandle is a handle to the internal metadata representation of a method. """
 def Equals(self,*__args):
  """
  Equals(self: RuntimeMethodHandle,handle: RuntimeMethodHandle) -> bool

  

   Indicates whether this instance is equal to a specified System.RuntimeMethodHandle.

  

   handle: A System.RuntimeMethodHandle to compare to this instance.

   Returns: true if handle is equal to the value of this instance; otherwise,false.

  Equals(self: RuntimeMethodHandle,obj: object) -> bool

  

   Indicates whether this instance is equal to a specified object.

  

   obj: A System.Object to compare to this instance.

   Returns: true if obj is a System.RuntimeMethodHandle and equal to the value of this instance; otherwise,

    false.
  """
  pass
 def GetFunctionPointer(self):
  """
  GetFunctionPointer(self: RuntimeMethodHandle) -> IntPtr

  

   Obtains a pointer to the method represented by this instance.

   Returns: A pointer to the method represented by this instance.
  """
  pass
 def GetHashCode(self):
  """
  GetHashCode(self: RuntimeMethodHandle) -> int

  

   Returns the hash code for this instance.

   Returns: A 32-bit signed integer hash code.
  """
  pass
 def GetObjectData(self,info,context):
  """
  GetObjectData(self: RuntimeMethodHandle,info: SerializationInfo,context: StreamingContext)

   Populates a System.Runtime.Serialization.SerializationInfo with the data necessary to 

    deserialize the field represented by this instance.

  

  

   info: The object to populate with serialization information.

   context: (Reserved) The place to store and retrieve serialized data.
  """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==y """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass
 def __str__(self,*args):
  pass
 Value=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the value of this instance.



Get: Value(self: RuntimeMethodHandle) -> IntPtr



"""





class IDisposable:
 """ Defines a method to release allocated resources. """
 def Dispose(self):
  """
  Dispose(self: IDisposable)

   Performs application-defined tasks associated with freeing,releasing,or resetting unmanaged 

    resources.
  """
  pass
 def __enter__(self,*args):
  """
  __enter__(self: IDisposable) -> object

  

   Provides the implementation of __enter__ for objects which implement IDisposable.
  """
  pass
 def __exit__(self,*args):
  """
  __exit__(self: IDisposable,exc_type: object,exc_value: object,exc_back: object)

   Provides the implementation of __exit__ for objects which implement IDisposable.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass



class Directory(object):
 """ Exposes static methods for creating,moving,and enumerating through directories and subdirectories. This class cannot be inherited. """
 @staticmethod
 def CreateDirectory(path,directorySecurity=None):
  """
  CreateDirectory(path: str,directorySecurity: DirectorySecurity) -> DirectoryInfo

  

   Creates all the directories in the specified path,applying the specified Windows security.

  

   path: The directory to create.

   directorySecurity: The access control to apply to the directory.

   Returns: A System.IO.DirectoryInfo object representing the newly created directory.

  CreateDirectory(path: str) -> DirectoryInfo

  

   Creates all directories and subdirectories in the specified path.

  

   path: The directory path to create.

   Returns: A System.IO.DirectoryInfo as specified by path.
  """
  pass
 @staticmethod
 def Delete(path,recursive=None):
  """
  Delete(path: str,recursive: bool)

   Deletes the specified directory and,if indicated,any subdirectories and files in the directory.

  

   path: The name of the directory to remove.

   recursive: true to remove directories,subdirectories,and files in path; otherwise,false.

  Delete(path: str)

   Deletes an empty directory from a specified path.

  

   path: The name of the empty directory to remove. This directory must be writable or empty.
  """
  pass
 @staticmethod
 def EnumerateDirectories(path,searchPattern=None,searchOption=None):
  """
  EnumerateDirectories(path: str,searchPattern: str,searchOption: SearchOption) -> IEnumerable[str]

  

   Returns an enumerable collection of directory names that match a search pattern in a specified 

    path,and optionally searches subdirectories.

  

  

   path: The directory to search.

   searchPattern: The search string to match against the names of directories in path.

   searchOption: One of the values of the System.IO.SearchOption enumeration that specifies whether the search 

    operation should include only the current directory or should include all subdirectories.The 

    default value is System.IO.SearchOption.TopDirectoryOnly.

  

   Returns: An enumerable collection of directory names in the directory specified by path and that match 

    searchPattern and searchOption.

  

  EnumerateDirectories(path: str,searchPattern: str) -> IEnumerable[str]

  

   Returns an enumerable collection of directory names that match a search pattern in a specified 

    path.

  

  

   path: The directory to search.

   searchPattern: The search string to match against the names of directories in path.

   Returns: An enumerable collection of directory names in the directory specified by path and that match 

    searchPattern.

  

  EnumerateDirectories(path: str) -> IEnumerable[str]

  

   Returns an enumerable collection of directory names in a specified path.

  

   path: The directory to search.

   Returns: An enumerable collection of directory names in the directory specified by path.
  """
  pass
 @staticmethod
 def EnumerateFiles(path,searchPattern=None,searchOption=None):
  """
  EnumerateFiles(path: str,searchPattern: str,searchOption: SearchOption) -> IEnumerable[str]

  

   Returns an enumerable collection of file names that match a search pattern in a specified path,

    and optionally searches subdirectories.

  

  

   path: The directory to search.

   searchPattern: The search string to match against the names of directories in path.

   searchOption: One of the values of the System.IO.SearchOption enumeration that specifies whether the search 

    operation should include only the current directory or should include all subdirectories.The 

    default value is System.IO.SearchOption.TopDirectoryOnly.

  

   Returns: An enumerable collection of file names in the directory specified by path and that match 

    searchPattern and searchOption.

  

  EnumerateFiles(path: str,searchPattern: str) -> IEnumerable[str]

  

   Returns an enumerable collection of file names that match a search pattern in a specified path.

  

   path: The directory to search.

   searchPattern: The search string to match against the names of directories in path.

   Returns: An enumerable collection of file names in the directory specified by path and that match 

    searchPattern.

  

  EnumerateFiles(path: str) -> IEnumerable[str]

  

   Returns an enumerable collection of file names in a specified path.

  

   path: The directory to search.

   Returns: An enumerable collection of file names in the directory specified by path.
  """
  pass
 @staticmethod
 def EnumerateFileSystemEntries(path,searchPattern=None,searchOption=None):
  """
  EnumerateFileSystemEntries(path: str,searchPattern: str,searchOption: SearchOption) -> IEnumerable[str]

  

   Returns an enumerable collection of file names and directory names that match a search pattern 

    in a specified path,and optionally searches subdirectories.

  

  

   path: The directory to search.

   searchPattern: The search string to match against the names of directories in path.

   searchOption: One of the values of the System.IO.SearchOption enumeration that specifies whether the search 

    operation should include only the current directory or should include all subdirectories.The 

    default value is System.IO.SearchOption.TopDirectoryOnly.

  

   Returns: An enumerable collection of file-system entries in the directory specified by path and that 

    match searchPattern and searchOption.

  

  EnumerateFileSystemEntries(path: str,searchPattern: str) -> IEnumerable[str]

  

   Returns an enumerable collection of file-system entries that match a search pattern in a 

    specified path.

  

  

   path: The directory to search.

   searchPattern: The search string to match against the names of directories in path.

   Returns: An enumerable collection of file-system entries in the directory specified by path and that 

    match searchPattern.

  

  EnumerateFileSystemEntries(path: str) -> IEnumerable[str]

  

   Returns an enumerable collection of file-system entries in a specified path.

  

   path: The directory to search.

   Returns: An enumerable collection of file-system entries in the directory specified by path.
  """
  pass
 @staticmethod
 def Exists(path):
  """
  Exists(path: str) -> bool

  

   Determines whether the given path refers to an existing directory on disk.

  

   path: The path to test.

   Returns: true if path refers to an existing directory; otherwise,false.
  """
  pass
 @staticmethod
 def GetAccessControl(path,includeSections=None):
  """
  GetAccessControl(path: str,includeSections: AccessControlSections) -> DirectorySecurity

  

   Gets a System.Security.AccessControl.DirectorySecurity object that encapsulates the specified 

    type of access control list (ACL) entries for a specified directory.

  

  

   path: The path to a directory containing a System.Security.AccessControl.DirectorySecurity object that 

    describes the file's access control list (ACL) information.

  

   includeSections: One of the System.Security.AccessControl.AccessControlSections values that specifies the type of 

    access control list (ACL) information to receive.

  

   Returns: A System.Security.AccessControl.DirectorySecurity object that encapsulates the access control 

    rules for the file described by the path parameter.

  

  GetAccessControl(path: str) -> DirectorySecurity

  

   Gets a System.Security.AccessControl.DirectorySecurity object that encapsulates the access 

    control list (ACL) entries for a specified directory.

  

  

   path: The path to a directory containing a System.Security.AccessControl.DirectorySecurity object that 

    describes the file's access control list (ACL) information.

  

   Returns: A System.Security.AccessControl.DirectorySecurity object that encapsulates the access control 

    rules for the file described by the path parameter.
  """
  pass
 @staticmethod
 def GetCreationTime(path):
  """
  GetCreationTime(path: str) -> DateTime

  

   Gets the creation date and time of a directory.

  

   path: The path of the directory.

   Returns: A System.DateTime structure set to the creation date and time for the specified directory. This 

    value is expressed in local time.
  """
  pass
 @staticmethod
 def GetCreationTimeUtc(path):
  """
  GetCreationTimeUtc(path: str) -> DateTime

  

   Gets the creation date and time,in Coordinated Universal Time (UTC) format,of a directory.

  

   path: The path of the directory.

   Returns: A System.DateTime structure set to the creation date and time for the specified directory. This 

    value is expressed in UTC time.
  """
  pass
 @staticmethod
 def GetCurrentDirectory():
  """
  GetCurrentDirectory() -> str

  

   Gets the current working directory of the application.

   Returns: A string that contains the path of the current working directory,and does not end with a 

    backslash (\).
  """
  pass
 @staticmethod
 def GetDirectories(path,searchPattern=None,searchOption=None):
  """
  GetDirectories(path: str,searchPattern: str,searchOption: SearchOption) -> Array[str]

  

   Gets the names of the directories (including their paths) that match the specified search 

    pattern in the current directory,and optionally searches subdirectories.

  

  

   path: The path to search.

   searchPattern: The search string to match against the names of files in path. The parameter cannot end in two 

    periods ("..") or contain two periods ("..") followed by System.IO.Path.DirectorySeparatorChar 

    or System.IO.Path.AltDirectorySeparatorChar,nor can it contain any of the characters in 

    System.IO.Path.InvalidPathChars.

  

   searchOption: One of the System.IO.SearchOption values that specifies whether the search operation should 

    include all subdirectories or only the current directory.

  

   Returns: A String array of directories that match the search pattern.

  GetDirectories(path: str,searchPattern: str) -> Array[str]

  

   Gets an array of directories (including their paths) that match the specified search pattern in 

    the current directory.

  

  

   path: The path to search.

   searchPattern: The search string to match against the names of files in path. The parameter cannot end in two 

    periods ("..") or contain two periods ("..") followed by System.IO.Path.DirectorySeparatorChar 

    or System.IO.Path.AltDirectorySeparatorChar,nor can it contain any of the characters in 

    System.IO.Path.InvalidPathChars.

  

   Returns: A String array of directories that match the search pattern.

  GetDirectories(path: str) -> Array[str]

  

   Gets the names of subdirectories (including their paths) in the specified directory.

  

   path: The path for which an array of subdirectory names is returned.

   Returns: An array of the names of subdirectories in path.
  """
  pass
 @staticmethod
 def GetDirectoryRoot(path):
  """
  GetDirectoryRoot(path: str) -> str

  

   Returns the volume information,root information,or both for the specified path.

  

   path: The path of a file or directory.

   Returns: A string containing the volume information,root information,or both for the specified path.
  """
  pass
 @staticmethod
 def GetFiles(path,searchPattern=None,searchOption=None):
  """
  GetFiles(path: str,searchPattern: str,searchOption: SearchOption) -> Array[str]

  

   Returns the names of files (including their paths) that match the specified search pattern in 

    the specified directory,using a value to determine whether to search subdirectories.

  

  

   path: The directory to search.

   searchPattern: The search string to match against the names of files in path. The parameter cannot end in two 

    periods ("..") or contain two periods ("..") followed by System.IO.Path.DirectorySeparatorChar 

    or System.IO.Path.AltDirectorySeparatorChar,nor can it contain any of the characters in 

    System.IO.Path.InvalidPathChars.

  

   searchOption: One of the System.IO.SearchOption values that specifies whether the search operation should 

    include all subdirectories or only the current directory.

  

   Returns: A String array containing the names of files in the specified directory that match the specified 

    search pattern. File names include the full path.

  

  GetFiles(path: str,searchPattern: str) -> Array[str]

  

   Returns the names of files (including their paths) that match the specified search pattern in 

    the specified directory.

  

  

   path: The directory to search.

   searchPattern: The search string to match against the names of files in path. The parameter cannot end in two 

    periods ("..") or contain two periods ("..") followed by System.IO.Path.DirectorySeparatorChar 

    or System.IO.Path.AltDirectorySeparatorChar,nor can it contain any of the characters in 

    System.IO.Path.InvalidPathChars.

  

   Returns: A String array containing the names of files in the specified directory that match the specified 

    search pattern. File names include the full path.

  

  GetFiles(path: str) -> Array[str]

  

   Returns the names of files (including their paths) in the specified directory.

  

   path: The directory from which to retrieve the files.

   Returns: A String array of file names in the specified directory.
  """
  pass
 @staticmethod
 def GetFileSystemEntries(path,searchPattern=None,searchOption=None):
  """
  GetFileSystemEntries(path: str,searchPattern: str,searchOption: SearchOption) -> Array[str]

  

   Gets an array of all the file names and directory names that match a search pattern in a 

    specified path,and optionally searches subdirectories.

  

  

   path: The directory to search.

   searchPattern: The string used to search for all files or directories that match its search pattern. The 

    default pattern is for all files and directories: "*"

  

   searchOption: The option that specifies whether the search operation should include only the current directory 

    or should include all subdirectories.The default value is 

    System.IO.SearchOption.TopDirectoryOnly.

  

   Returns: An array of file system entries that match the search criteria.

  GetFileSystemEntries(path: str,searchPattern: str) -> Array[str]

  

   Returns an array of file system entries that match the specified search criteria.

  

   path: The path to be searched.

   searchPattern: The search string to match against the names of files in path. The searchPattern parameter 

    cannot end in two periods ("..") or contain two periods ("..") followed by 

    System.IO.Path.DirectorySeparatorChar or System.IO.Path.AltDirectorySeparatorChar,nor can it 

    contain any of the characters in System.IO.Path.InvalidPathChars.

  

   Returns: An array of file system entries that match the search criteria.

  GetFileSystemEntries(path: str) -> Array[str]

  

   Returns the names of all files and subdirectories in the specified directory.

  

   path: The directory for which file and subdirectory names are returned.

   Returns: An array that contains the names of files and subdirectories in the specified directory.
  """
  pass
 @staticmethod
 def GetLastAccessTime(path):
  """
  GetLastAccessTime(path: str) -> DateTime

  

   Returns the date and time the specified file or directory was last accessed.

  

   path: The file or directory for which to obtain access date and time information.

   Returns: A System.DateTime structure set to the date and time the specified file or directory was last 

    accessed. This value is expressed in local time.
  """
  pass
 @staticmethod
 def GetLastAccessTimeUtc(path):
  """
  GetLastAccessTimeUtc(path: str) -> DateTime

  

   Returns the date and time,in Coordinated Universal Time (UTC) format,that the specified file 

    or directory was last accessed.

  

  

   path: The file or directory for which to obtain access date and time information.

   Returns: A System.DateTime structure set to the date and time the specified file or directory was last 

    accessed. This value is expressed in UTC time.
  """
  pass
 @staticmethod
 def GetLastWriteTime(path):
  """
  GetLastWriteTime(path: str) -> DateTime

  

   Returns the date and time the specified file or directory was last written to.

  

   path: The file or directory for which to obtain modification date and time information.

   Returns: A System.DateTime structure set to the date and time the specified file or directory was last 

    written to. This value is expressed in local time.
  """
  pass
 @staticmethod
 def GetLastWriteTimeUtc(path):
  """
  GetLastWriteTimeUtc(path: str) -> DateTime

  

   Returns the date and time,in Coordinated Universal Time (UTC) format,that the specified file 

    or directory was last written to.

  

  

   path: The file or directory for which to obtain modification date and time information.

   Returns: A System.DateTime structure set to the date and time the specified file or directory was last 

    written to. This value is expressed in UTC time.
  """
  pass
 @staticmethod
 def GetLogicalDrives():
  """
  GetLogicalDrives() -> Array[str]

  

   Retrieves the names of the logical drives on this computer in the form "<drive letter>:\".

   Returns: The logical drives on this computer.
  """
  pass
 @staticmethod
 def GetParent(path):
  """
  GetParent(path: str) -> DirectoryInfo

  

   Retrieves the parent directory of the specified path,including both absolute and relative paths.

  

   path: The path for which to retrieve the parent directory.

   Returns: The parent directory,or null if path is the root directory,including the root of a UNC server 

    or share name.
  """
  pass
 @staticmethod
 def Move(sourceDirName,destDirName):
  """
  Move(sourceDirName: str,destDirName: str)

   Moves a file or a directory and its contents to a new location.

  

   sourceDirName: The path of the file or directory to move.

   destDirName: The path to the new location for sourceDirName. If sourceDirName is a file,then destDirName 

    must also be a file name.
  """
  pass
 @staticmethod
 def SetAccessControl(path,directorySecurity):
  """
  SetAccessControl(path: str,directorySecurity: DirectorySecurity)

   Applies access control list (ACL) entries described by a 

    System.Security.AccessControl.DirectorySecurity object to the specified directory.

  

  

   path: A directory to add or remove access control list (ACL) entries from.

   directorySecurity: A System.Security.AccessControl.DirectorySecurity object that describes an ACL entry to apply to 

    the directory described by the path parameter.
  """
  pass
 @staticmethod
 def SetCreationTime(path,creationTime):
  """
  SetCreationTime(path: str,creationTime: DateTime)

   Sets the creation date and time for the specified file or directory.

  

   path: The file or directory for which to set the creation date and time information.

   creationTime: A System.DateTime containing the value to set for the creation date and time of path. This value 

    is expressed in local time.
  """
  pass
 @staticmethod
 def SetCreationTimeUtc(path,creationTimeUtc):
  """
  SetCreationTimeUtc(path: str,creationTimeUtc: DateTime)

   Sets the creation date and time,in Coordinated Universal Time (UTC) format,for the specified 

    file or directory.

  

  

   path: The file or directory for which to set the creation date and time information.

   creationTimeUtc: A System.DateTime containing the value to set for the creation date and time of path. This value 

    is expressed in UTC time.
  """
  pass
 @staticmethod
 def SetCurrentDirectory(path):
  """
  SetCurrentDirectory(path: str)

   Sets the application's current working directory to the specified directory.

  

   path: The path to which the current working directory is set.
  """
  pass
 @staticmethod
 def SetLastAccessTime(path,lastAccessTime):
  """
  SetLastAccessTime(path: str,lastAccessTime: DateTime)

   Sets the date and time the specified file or directory was last accessed.

  

   path: The file or directory for which to set the access date and time information.

   lastAccessTime: A System.DateTime containing the value to set for the access date and time of path. This value 

    is expressed in local time.
  """
  pass
 @staticmethod
 def SetLastAccessTimeUtc(path,lastAccessTimeUtc):
  """
  SetLastAccessTimeUtc(path: str,lastAccessTimeUtc: DateTime)

   Sets the date and time,in Coordinated Universal Time (UTC) format,that the specified file or 

    directory was last accessed.

  

  

   path: The file or directory for which to set the access date and time information.

   lastAccessTimeUtc: A System.DateTime containing the value to set for the access date and time of path. This value 

    is expressed in UTC time.
  """
  pass
 @staticmethod
 def SetLastWriteTime(path,lastWriteTime):
  """
  SetLastWriteTime(path: str,lastWriteTime: DateTime)

   Sets the date and time a directory was last written to.

  

   path: The path of the directory.

   lastWriteTime: The date and time the directory was last written to. This value is expressed in local time.
  """
  pass
 @staticmethod
 def SetLastWriteTimeUtc(path,lastWriteTimeUtc):
  """
  SetLastWriteTimeUtc(path: str,lastWriteTimeUtc: DateTime)

   Sets the date and time,in Coordinated Universal Time (UTC) format,that a directory was last 

    written to.

  

  

   path: The path of the directory.

   lastWriteTimeUtc: The date and time the directory was last written to. This value is expressed in UTC time.
  """
  pass
 __all__=[
  'CreateDirectory',
  'Delete',
  'EnumerateDirectories',
  'EnumerateFiles',
  'EnumerateFileSystemEntries',
  'Exists',
  'GetAccessControl',
  'GetCreationTime',
  'GetCreationTimeUtc',
  'GetCurrentDirectory',
  'GetDirectories',
  'GetDirectoryRoot',
  'GetFiles',
  'GetFileSystemEntries',
  'GetLastAccessTime',
  'GetLastAccessTimeUtc',
  'GetLastWriteTime',
  'GetLastWriteTimeUtc',
  'GetLogicalDrives',
  'GetParent',
  'Move',
  'SetAccessControl',
  'SetCreationTime',
  'SetCreationTimeUtc',
  'SetCurrentDirectory',
  'SetLastAccessTime',
  'SetLastAccessTimeUtc',
  'SetLastWriteTime',
  'SetLastWriteTimeUtc',
 ]




# encoding: utf-8
# module System.Windows.Media.Media3D.Converters calls itself Converters
# from PresentationCore,Version=4.0.0.0,Culture=neutral,PublicKeyToken=31bf3856ad364e35
# by generator 1.145
""" NamespaceTracker represent a CLS namespace. """
# no imports

# no functions
# classes

class Matrix3DValueSerializer(ValueSerializer):
 """
 Converts instances of System.String to and from instances of System.Windows.Media.Media3D.Matrix3D.

 

 Matrix3DValueSerializer()
 """
 def CanConvertFromString(self,value,context):
  """
  CanConvertFromString(self: Matrix3DValueSerializer,value: str,context: IValueSerializerContext) -> bool

  

   Determines if conversion from a given System.String to an instance of 

    System.Windows.Media.Media3D.Matrix3D is possible.

  

  

   value: String to evaluate for conversion.

   context: Context information used for conversion.

   Returns: true if the value can be converted; otherwise,false.
  """
  pass
 def CanConvertToString(self,value,context):
  """
  CanConvertToString(self: Matrix3DValueSerializer,value: object,context: IValueSerializerContext) -> bool

  

   Determines if an instance of System.Windows.Media.Media3D.Matrix3D can be converted to a 

    System.String.

  

  

   value: Instance of System.Windows.Media.Media3D.Matrix3D to evaluate for conversion.

   context: Context information used for conversion.

   Returns: true if value can be converted into a System.String; otherwise,false.
  """
  pass
 def ConvertFromString(self,value,context):
  """
  ConvertFromString(self: Matrix3DValueSerializer,value: str,context: IValueSerializerContext) -> object

  

   Converts a System.String into a System.Windows.Media.Media3D.Matrix3D.

  

   value: System.String value to convert into a System.Windows.Media.Media3D.Matrix3D.

   context: Context information used for conversion.

   Returns: A new instance of System.Windows.Media.Media3D.Matrix3D based on the supplied value.
  """
  pass
 def ConvertToString(self,value,context):
  """
  ConvertToString(self: Matrix3DValueSerializer,value: object,context: IValueSerializerContext) -> str

  

   Converts an instance of System.Windows.Media.Media3D.Matrix3D to a System.String.

  

   value: Instance of System.Windows.Media.Media3D.Matrix3D to evaluate for conversion.

   context: Context information used for conversion.

   Returns: A System.String representation of the supplied System.Windows.Media.Media3D.Matrix3D object.
  """
  pass

class Point3DCollectionValueSerializer(ValueSerializer):
 """
 Converts instances of System.String to and from instances of System.Windows.Media.Media3D.Point3DCollection.

 

 Point3DCollectionValueSerializer()
 """
 def CanConvertFromString(self,value,context):
  """
  CanConvertFromString(self: Point3DCollectionValueSerializer,value: str,context: IValueSerializerContext) -> bool

  

   Determines if conversion from a given System.String to an instance of 

    System.Windows.Media.Media3D.Point3DCollection is possible.

  

  

   value: String to evaluate for conversion.

   context: Context information used for conversion.

   Returns: true if the value can be converted; otherwise,false.
  """
  pass
 def CanConvertToString(self,value,context):
  """
  CanConvertToString(self: Point3DCollectionValueSerializer,value: object,context: IValueSerializerContext) -> bool

  

   Determines if an instance of System.Windows.Media.Media3D.Point3DCollection can be converted to 

    a System.String.

  

  

   value: Instance of System.Windows.Media.Media3D.Point3DCollection to evaluate for conversion.

   context: Context information used for conversion.

   Returns: true if value can be converted into a System.String; otherwise,false.
  """
  pass
 def ConvertFromString(self,value,context):
  """
  ConvertFromString(self: Point3DCollectionValueSerializer,value: str,context: IValueSerializerContext) -> object

  

   Converts a System.String into a System.Windows.Media.Media3D.Point3DCollection.

  

   value: System.String value to convert into a System.Windows.Media.Media3D.Point3DCollection.

   context: Context information used for conversion.

   Returns: A new instance of System.Windows.Media.Media3D.Point3DCollection based on the supplied value.
  """
  pass
 def ConvertToString(self,value,context):
  """
  ConvertToString(self: Point3DCollectionValueSerializer,value: object,context: IValueSerializerContext) -> str

  

   Converts an instance of System.Windows.Media.Media3D.Point3DCollection to a System.String.

  

   value: Instance of System.Windows.Media.Media3D.Point3DCollection to evaluate for conversion.

   context: Context information used for conversion.

   Returns: A System.String representation of the supplied System.Windows.Media.Media3D.Point3DCollection 

    object.
  """
  pass

class Point3DValueSerializer(ValueSerializer):
 """
 Converts instances of System.String to and from instances of System.Windows.Media.Media3D.Point3D.

 

 Point3DValueSerializer()
 """
 def CanConvertFromString(self,value,context):
  """
  CanConvertFromString(self: Point3DValueSerializer,value: str,context: IValueSerializerContext) -> bool

  

   Determines if conversion from a given System.String to an instance of 

    System.Windows.Media.Media3D.Point3D is possible.

  

  

   value: String to evaluate for conversion.

   context: Context information used for conversion.

   Returns: true if the value can be converted; otherwise,false.
  """
  pass
 def CanConvertToString(self,value,context):
  """
  CanConvertToString(self: Point3DValueSerializer,value: object,context: IValueSerializerContext) -> bool

  

   Determines if an instance of System.Windows.Media.Media3D.Point3D can be converted to a 

    System.String.

  

  

   value: Instance of System.Windows.Media.Media3D.Point3D to evaluate for conversion.

   context: Context information used for conversion.

   Returns: true if value can be converted into a System.String; otherwise,false.
  """
  pass
 def ConvertFromString(self,value,context):
  """
  ConvertFromString(self: Point3DValueSerializer,value: str,context: IValueSerializerContext) -> object

  

   Converts a System.String into a System.Windows.Media.Media3D.Point3D.

  

   value: System.String value to convert into a System.Windows.Media.Media3D.Point3D.

   context: Context information used for conversion.

   Returns: A new instance of System.Windows.Media.Media3D.Point3D based on the supplied value.
  """
  pass
 def ConvertToString(self,value,context):
  """
  ConvertToString(self: Point3DValueSerializer,value: object,context: IValueSerializerContext) -> str

  

   Converts an instance of System.Windows.Media.Media3D.Point3D to a System.String.

  

   value: Instance of System.Windows.Media.Media3D.Point3D to evaluate for conversion.

   context: Context information used for conversion.

   Returns: A System.String representation of the supplied System.Windows.Media.Media3D.Point3D object.
  """
  pass

class Point4DValueSerializer(ValueSerializer):
 """
 Converts instances of System.String to and from instances of System.Windows.Media.Media3D.Point4D.

 

 Point4DValueSerializer()
 """
 def CanConvertFromString(self,value,context):
  """
  CanConvertFromString(self: Point4DValueSerializer,value: str,context: IValueSerializerContext) -> bool

  

   Determines if conversion from a given System.String to an instance of 

    System.Windows.Media.Media3D.Point4D is possible.

  

  

   value: String to evaluate for conversion.

   context: Context information used for conversion.

   Returns: true if the value can be converted; otherwise,false.
  """
  pass
 def CanConvertToString(self,value,context):
  """
  CanConvertToString(self: Point4DValueSerializer,value: object,context: IValueSerializerContext) -> bool

  

   Determines if an instance of System.Windows.Media.Media3D.Point4D can be converted to a 

    System.String.

  

  

   value: Instance of System.Windows.Media.Media3D.Point4D to evaluate for conversion.

   context: Context information used for conversion.

   Returns: true if value can be converted into a System.String; otherwise,false.
  """
  pass
 def ConvertFromString(self,value,context):
  """
  ConvertFromString(self: Point4DValueSerializer,value: str,context: IValueSerializerContext) -> object

  

   Converts a System.String into a System.Windows.Media.Media3D.Point4D.

  

   value: System.String value to convert into a System.Windows.Media.Media3D.Point4D.

   context: Context information used for conversion.

   Returns: A new instance of System.Windows.Media.Media3D.Point4D based on the supplied value.
  """
  pass
 def ConvertToString(self,value,context):
  """
  ConvertToString(self: Point4DValueSerializer,value: object,context: IValueSerializerContext) -> str

  

   Converts an instance of System.Windows.Media.Media3D.Point4D to a System.String.

  

   value: Instance of System.Windows.Media.Media3D.Point4D to evaluate for conversion.

   context: Context information used for conversion.

   Returns: A System.String representation of the supplied System.Windows.Media.Media3D.Point4D object.
  """
  pass

class QuaternionValueSerializer(ValueSerializer):
 """
 Converts instances of System.String to and from instances of System.Windows.Media.Media3D.Quaternion.

 

 QuaternionValueSerializer()
 """
 def CanConvertFromString(self,value,context):
  """
  CanConvertFromString(self: QuaternionValueSerializer,value: str,context: IValueSerializerContext) -> bool

  

   Determines if conversion from a given System.String to an instance of 

    System.Windows.Media.Media3D.Quaternion is possible.

  

  

   value: String to evaluate for conversion.

   context: Context information used for conversion.

   Returns: true if the value can be converted; otherwise,false.
  """
  pass
 def CanConvertToString(self,value,context):
  """
  CanConvertToString(self: QuaternionValueSerializer,value: object,context: IValueSerializerContext) -> bool

  

   Determines if an instance of System.Windows.Media.Media3D.Quaternion can be converted to a 

    System.String.

  

  

   value: Instance of System.Windows.Media.Media3D.Quaternion to evaluate for conversion.

   context: Context information used for conversion.

   Returns: true if value can be converted into a System.String; otherwise,false.
  """
  pass
 def ConvertFromString(self,value,context):
  """
  ConvertFromString(self: QuaternionValueSerializer,value: str,context: IValueSerializerContext) -> object

  

   Converts a System.String into a System.Windows.Media.Media3D.Quaternion.

  

   value: System.String value to convert into a System.Windows.Media.Media3D.Quaternion.

   context: Context information used for conversion.

   Returns: A new instance of System.Windows.Media.Media3D.Quaternion based on the supplied value.
  """
  pass
 def ConvertToString(self,value,context):
  """
  ConvertToString(self: QuaternionValueSerializer,value: object,context: IValueSerializerContext) -> str

  

   Converts an instance of System.Windows.Media.Media3D.Quaternion to a System.String.

  

   value: Instance of System.Windows.Media.Media3D.Quaternion to evaluate for conversion.

   context: Context information used for conversion.

   Returns: A System.String representation of the supplied System.Windows.Media.Media3D.Quaternion object.
  """
  pass

class Rect3DValueSerializer(ValueSerializer):
 """
 Converts instances of System.String to and from instances of System.Windows.Media.Media3D.Rect3D.

 

 Rect3DValueSerializer()
 """
 def CanConvertFromString(self,value,context):
  """
  CanConvertFromString(self: Rect3DValueSerializer,value: str,context: IValueSerializerContext) -> bool

  

   Determines if conversion from a given System.String to an instance of 

    System.Windows.Media.Media3D.Rect3D is possible.

  

  

   value: String to evaluate for conversion.

   context: Context information used for conversion.

   Returns: true if the value can be converted; otherwise,false.
  """
  pass
 def CanConvertToString(self,value,context):
  """
  CanConvertToString(self: Rect3DValueSerializer,value: object,context: IValueSerializerContext) -> bool

  

   Determines if an instance of System.Windows.Media.Media3D.Rect3D can be converted to a 

    System.String.

  

  

   value: Instance of System.Windows.Media.Media3D.Rect3D to evaluate for conversion.

   context: Context information used for conversion.

   Returns: true if value can be converted into a System.String; otherwise,false.
  """
  pass
 def ConvertFromString(self,value,context):
  """
  ConvertFromString(self: Rect3DValueSerializer,value: str,context: IValueSerializerContext) -> object

  

   Converts a System.String into a System.Windows.Media.Media3D.Rect3D.

  

   value: System.String value to convert into a System.Windows.Media.Media3D.Rect3D.

   context: Context information used for conversion.

   Returns: A new instance of System.Windows.Media.Media3D.Rect3D based on the supplied value.
  """
  pass
 def ConvertToString(self,value,context):
  """
  ConvertToString(self: Rect3DValueSerializer,value: object,context: IValueSerializerContext) -> str

  

   Converts an instance of System.Windows.Media.Media3D.Rect3D to a System.String.

  

   value: Instance of System.Windows.Media.Media3D.Rect3D to evaluate for conversion.

   context: Context information used for conversion.

   Returns: A System.String representation of the supplied System.Windows.Media.Media3D.Rect3D object.
  """
  pass

class Size3DValueSerializer(ValueSerializer):
 """
 Converts instances of System.String to and from instances of System.Windows.Media.Media3D.Size3D.

 

 Size3DValueSerializer()
 """
 def CanConvertFromString(self,value,context):
  """
  CanConvertFromString(self: Size3DValueSerializer,value: str,context: IValueSerializerContext) -> bool

  

   Determines if conversion from a given System.String to an instance of 

    System.Windows.Media.Media3D.Size3D is possible.

  

  

   value: String to evaluate for conversion.

   context: Context information used for conversion.

   Returns: true if the value can be converted; otherwise,false.
  """
  pass
 def CanConvertToString(self,value,context):
  """
  CanConvertToString(self: Size3DValueSerializer,value: object,context: IValueSerializerContext) -> bool

  

   Determines if an instance of System.Windows.Media.Media3D.Size3D can be converted to a 

    System.String.

  

  

   value: Instance of System.Windows.Media.Media3D.Size3D to evaluate for conversion.

   context: Context information used for conversion.

   Returns: true if value can be converted into a System.String; otherwise,false.
  """
  pass
 def ConvertFromString(self,value,context):
  """
  ConvertFromString(self: Size3DValueSerializer,value: str,context: IValueSerializerContext) -> object

  

   Converts a System.String into a System.Windows.Media.Media3D.Size3D.

  

   value: System.String value to convert into a System.Windows.Media.Media3D.Size3D.

   context: Context information used for conversion.

   Returns: A new instance of System.Windows.Media.Media3D.Size3D based on the supplied value.
  """
  pass
 def ConvertToString(self,value,context):
  """
  ConvertToString(self: Size3DValueSerializer,value: object,context: IValueSerializerContext) -> str

  

   Converts an instance of System.Windows.Media.Media3D.Size3D to a System.String.

  

   value: Instance of System.Windows.Media.Media3D.Size3D to evaluate for conversion.

   context: Context information used for conversion.

   Returns: A System.String representation of the supplied System.Windows.Media.Media3D.Size3D object.
  """
  pass

class Vector3DCollectionValueSerializer(ValueSerializer):
 """
 Converts instances of System.String to and from instances of System.Windows.Media.Media3D.Vector3DCollection.

 

 Vector3DCollectionValueSerializer()
 """
 def CanConvertFromString(self,value,context):
  """
  CanConvertFromString(self: Vector3DCollectionValueSerializer,value: str,context: IValueSerializerContext) -> bool

  

   Determines if conversion from a given System.String to an instance of 

    System.Windows.Media.Media3D.Vector3DCollection is possible.

  

  

   value: String to evaluate for conversion.

   context: Context information used for conversion.

   Returns: true if the value can be converted; otherwise,false.
  """
  pass
 def CanConvertToString(self,value,context):
  """
  CanConvertToString(self: Vector3DCollectionValueSerializer,value: object,context: IValueSerializerContext) -> bool

  

   Determines if an instance of System.Windows.Media.Media3D.Vector3DCollection can be converted to 

    a System.String.

  

  

   value: Instance of System.Windows.Media.Media3D.Vector3DCollection to evaluate for conversion.

   context: Context information used for conversion.

   Returns: true if value can be converted into a System.String; otherwise,false.
  """
  pass
 def ConvertFromString(self,value,context):
  """
  ConvertFromString(self: Vector3DCollectionValueSerializer,value: str,context: IValueSerializerContext) -> object

  

   Converts a System.String into a System.Windows.Media.Media3D.Vector3DCollection.

  

   value: System.String value to convert into a System.Windows.Media.Media3D.Vector3DCollection.

   context: Context information used for conversion.

   Returns: A new instance of System.Windows.Media.Media3D.Vector3DCollection based on the supplied value.
  """
  pass
 def ConvertToString(self,value,context):
  """
  ConvertToString(self: Vector3DCollectionValueSerializer,value: object,context: IValueSerializerContext) -> str

  

   Converts an instance of System.Windows.Media.Media3D.Vector3DCollection to a System.String.

  

   value: Instance of System.Windows.Media.Media3D.Vector3DCollection to evaluate for conversion.

   context: Context information used for conversion.

   Returns: A System.String representation of the supplied System.Windows.Media.Media3D.Vector3DCollection 

    object.
  """
  pass

class Vector3DValueSerializer(ValueSerializer):
 """
 Converts instances of System.String to and from instances of System.Windows.Media.Media3D.Vector3D.

 

 Vector3DValueSerializer()
 """
 def CanConvertFromString(self,value,context):
  """
  CanConvertFromString(self: Vector3DValueSerializer,value: str,context: IValueSerializerContext) -> bool

  

   Determines if conversion from a given System.String to an instance of 

    System.Windows.Media.Media3D.Vector3D is possible.

  

  

   value: String to evaluate for conversion.

   context: Context information used for conversion.

   Returns: true if the value can be converted; otherwise,false.
  """
  pass
 def CanConvertToString(self,value,context):
  """
  CanConvertToString(self: Vector3DValueSerializer,value: object,context: IValueSerializerContext) -> bool

  

   Determines if an instance of System.Windows.Media.Media3D.Vector3D can be converted to a 

    System.String.

  

  

   value: Instance of System.Windows.Media.Media3D.Vector3D to evaluate for conversion.

   context: Context information used for conversion.

   Returns: true if value can be converted into a System.String; otherwise,false.
  """
  pass
 def ConvertFromString(self,value,context):
  """
  ConvertFromString(self: Vector3DValueSerializer,value: str,context: IValueSerializerContext) -> object

  

   Converts a System.String into a System.Windows.Media.Media3D.Vector3D.

  

   value: System.String value to convert into a System.Windows.Media.Media3D.Vector3D.

   context: Context information used for conversion.

   Returns: A new instance of System.Windows.Media.Media3D.Vector3D based on the supplied value.
  """
  pass
 def ConvertToString(self,value,context):
  """
  ConvertToString(self: Vector3DValueSerializer,value: object,context: IValueSerializerContext) -> str

  

   Converts an instance of System.Windows.Media.Media3D.Vector3D to a System.String.

  

   value: Instance of System.Windows.Media.Media3D.Vector3D to evaluate for conversion.

   context: Context information used for conversion.

   Returns: A System.String representation of the supplied System.Windows.Media.Media3D.Vector3D object.
  """
  pass




class TypeDescriptionProviderAttribute(Attribute,_Attribute):
 """
 Specifies the custom type description provider for a class. This class cannot be inherited.

 

 TypeDescriptionProviderAttribute(typeName: str)

 TypeDescriptionProviderAttribute(type: Type)
 """
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type,typeName: str)

  __new__(cls: type,type: Type)
  """
  pass
 TypeName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the type name for the type description provider.



Get: TypeName(self: TypeDescriptionProviderAttribute) -> str



"""





class IODescriptionAttribute(DescriptionAttribute,_Attribute):
 """
 Sets the description visual designers can display when referencing an event,extender,or property.

 

 IODescriptionAttribute(description: str)
 """
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,description):
  """ __new__(cls: type,description: str) """
  pass
 Description=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the description.



Get: Description(self: IODescriptionAttribute) -> str



"""

 DescriptionValue=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the string stored as the description.



"""





class InputLanguageChangedEventArgs(EventArgs):
 """
 Provides data for the System.Windows.Forms.Form.InputLanguageChanged event.

 

 InputLanguageChangedEventArgs(culture: CultureInfo,charSet: Byte)

 InputLanguageChangedEventArgs(inputLanguage: InputLanguage,charSet: Byte)
 """
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type,culture: CultureInfo,charSet: Byte)

  __new__(cls: type,inputLanguage: InputLanguage,charSet: Byte)
  """
  pass
 CharSet=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the character set associated with the new input language.



Get: CharSet(self: InputLanguageChangedEventArgs) -> Byte



"""

 Culture=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the locale of the input language.



Get: Culture(self: InputLanguageChangedEventArgs) -> CultureInfo



"""

 InputLanguage=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating the input language.



Get: InputLanguage(self: InputLanguageChangedEventArgs) -> InputLanguage



"""





from typing import Tuple, Set, Iterable, List


class DuctFittingAndAccessoryPressureDropUIDataItem:
    @property
    def IsValidObject(self) -> bool: ...
    def GetEntity(self) -> Entity: ...
    def SetEntity(self, entity: Entity) -> None: ...
    def GetDuctFittingAndAccessoryData(self) -> DuctFittingAndAccessoryData: ...
    def Dispose(self) -> None: ...


class DuctFittingAndAccessoryPressureDropUIData:
    @property
    def IsValidObject(self) -> bool: ...
    def GetUnits(self) -> Units: ...
    def GetUIDataItems(self) -> List[DuctFittingAndAccessoryPressureDropUIDataItem]: ...
    def Dispose(self) -> None: ...


class IDuctFittingAndAccessoryPressureDropUIServer:
    def GetDBServerId(self) -> Guid: ...
    def ShowSettings(self, data: DuctFittingAndAccessoryPressureDropUIData) -> bool: ...



""" TaskDialogs Wrappers"""  #

import sys
from rpw import UI
from rpw.exceptions import RpwValueError
from rpw.base import BaseObjectWrapper, BaseObject

class Alert():
    """
    A Simple Revit TaskDialog for displaying quick messages

    Usage:
        >>> from rpw.ui.forms import Alert
        >>> Alert('Your Message', title="Title", header="Header Text")
        >>> Alert('You need to select Something', exit=True)

    Args:
        message (str): TaskDialog Content
        title (str, optional): TaskDialog Title
        header (str, optional): TaskDialog content header
        exit (bool, optional): Exit Script after Dialog.
            Useful for displayin Errors. Default is False

    """
    def __init__(self, content, title='Alert', header='', exit=False):
        dialog = UI.TaskDialog(title)
        dialog.TitleAutoPrefix = False
        dialog.MainInstruction = header
        dialog.MainContent = content
        self.result = dialog.Show()

        if exit:
            sys.exit(1)

class CommandLink(BaseObject):
    """
    Command Link Helper Class

    Usage:
        >>> from rpw.ui.forms import CommandLink, TaskDialog
        >>> CommandLink('Open Dialog', return_value=func_to_open)
        >>> TaskDialog('Title', commands=[CommandLink])

    Args:
        text (str): Command Text
        subtext (str, optional): Button Subtext
        return_value (any, optional): Value returned if button is clicked.
            If none is provided, text is returned.

    """
    def __init__(self, text, subtext='', return_value=None):
        self._id = None  # This will later be set to TaskDialogCommandLinkId(n)
        self.text = text
        self.subtext = subtext
        self.return_value = return_value if return_value is not None else text

    def __repr__(self):
        return super(CommandLink, self).__repr__(data={'id': self._id,
                                                       'text':self.text})


class TaskDialog(BaseObjectWrapper):
    """
    Task Dialog Wrapper

    >>> from rpw.ui.forms import CommandLink, TaskDialog
    >>> commands= [CommandLink('Open Dialog', return_value='Open'),
    >>> ...           CommandLink('Command', return_value=lambda: True)]
    >>> ...
    >>> dialog = TaskDialog('This TaskDialog has Buttons ',
    >>> ...                 title_prefix=False,
    >>> ...                 content="Further Instructions",
    >>> ...                 commands=commands,
    >>> ...                 buttons=['Cancel', 'OK', 'RETRY'],
    >>> ...                 footer='It has a footer',
    >>> ...                 # verification_text='Add Verification Checkbox',
    >>> ...                 # expanded_content='Add Expanded Content',
    >>> ...                 show_close=True)
    >>> dialog.show()
    'Open'

    Wrapped Element:
        self._revit_object = `Revit.UI.TaskDialog`

    Args:
        content (str): Main text of TaskDialog.
        commands (list, optional): List of CommandLink Instances.
            Default is no buttons.
        buttons (list, optional): List of TaskDialogCommonButtons names.
            Default is no buttons. 'Close' is shown if no commands are passed.
        title (str, optional): Title of TaskDialog. Default is 'Task Dialog'.p
        instruction (str, optional): Main Instruction.
        footer (str, optional): Footer Text. Default is ``blank``.
        expanded_content (str, optional): Expandable Text. Default is ``blank``.
        verification_text (str, optional): Checkbox text. Default is ``blank``.
        title_prefix (bool, optional): Prefix Title with app name.
            Default is ``False``
        show_close (bool, optional): Show X to close. Default is False.

    """
    _revit_object_class = UI.TaskDialog
    _common_buttons = ['Ok', 'Yes', 'No', 'Cancel', 'Retry', 'Close']

    def __init__(self, instruction, commands=None, buttons=None,
                 title='Task Dialog', content='',
                 title_prefix=False, show_close=False,
                 footer='', expanded_content='', verification_text=''
                 ):

        super(TaskDialog, self).__init__(UI.TaskDialog(title))
        self.dialog = self._revit_object

        # Settings
        self.dialog.TitleAutoPrefix = title_prefix
        self.dialog.AllowCancellation = show_close

        # Properties
        self.dialog.Title = title
        self.dialog.MainInstruction = instruction
        self.dialog.MainContent = content
        self.dialog.FooterText = footer
        self.dialog.ExpandedContent = expanded_content
        self.dialog.VerificationText = verification_text
        self.verification_checked = None if not verification_text else False

        # Add Buttons
        self.buttons = buttons or []
        common_buttons_names = []
        for button_name in [b.capitalize() for b in self.buttons]:
            if button_name not in self._common_buttons:
                raise RpwValueError('TaskDialogCommonButtons member', button_name)
            button_full_name = 'UI.TaskDialogCommonButtons.' + button_name
            common_buttons_names.append(button_full_name)

        if common_buttons_names:
            common_buttons = eval('|'.join(common_buttons_names))
            self.dialog.CommonButtons = common_buttons

        # Set Default Button
        self.dialog.DefaultButton = UI.TaskDialogResult["None"]

        # Validate Commands
        commands = commands or []
        if len(commands) > 4:
            raise RpwValueError('4 or less command links', len(commands))

        # Process Commands
        self.commands = {}
        for link_index, command_link in enumerate(commands, 1):
            command_id = 'CommandLink{}'.format(link_index)
            command_link._id = getattr(UI.TaskDialogCommandLinkId, command_id)
            self.commands[command_id] = command_link
            self.dialog.AddCommandLink(command_link._id,
                                       command_link.text,
                                       command_link.subtext)

    def show(self, exit=False):
        """
        Show TaskDialog

        Args:
            exit (bool, optional): Exit Script after Dialog. Useful for
                displaying Errors. Default is False.

        Returns:
            Returns is ``False`` if dialog is Cancelled (X or Cancel button).
            If CommandLink button is clicked, ``CommandLink.return_value``
            is returned - if one was not provided, ``CommandLink.text`` is used.
            If CommonButtons are clicked ``TaskDialog.TaskDialogResult`` name is
            returned ie('Close', 'Retry', 'Yes', etc).
        """
        self.result = self.dialog.Show()

        try:
            self.verification_checked = self.dialog.WasVerificationChecked()
        except:
            self.verification_checked = None

        # Handle Cancel
        if self.result == UI.TaskDialogResult.Cancel:
            if exit:
                sys.exit(1)
            return None

        # If result is a CommandLink, return Return Value else Result
        command_link = self.commands.get(str(self.result))
        if command_link:
            return command_link.return_value
        else:
            return self.result.ToString()



if __name__ == '__main__':
    Alert('Test Alert!')

    def sample_callback():
        print('Calling B')
        d = UI.TaskDialog("Revit Build Information")
        d.MainInstruction = "Button 1"
        d.Show()


    from rpw.ui.forms.taskdialog import *
    commands = [
                CommandLink('TestTitle', return_value=sample_callback, subtext='test subtext'),
                CommandLink('TestTitle2', return_value=lambda: 'Empty', subtext='test subtext2')
                ]

    t = TaskDialog(commands=commands, buttons=['Yes'])



class Debug(object):
 """ Provides a set of methods and properties that help debug your code. This class cannot be inherited. """
 @staticmethod
 def Assert(condition,message=None,*__args):
  """
  Assert(condition: bool,message: str,detailMessage: str)

   Checks for a condition; if the condition is false,outputs two specified messages and displays a 

    message box that shows the call stack.

  

  

   condition: The conditional expression to evaluate. If the condition is true,the specified messages are not 

    sent and the message box is not displayed.

  

   message: The message to send to the System.Diagnostics.Trace.Listeners collection.

   detailMessage: The detailed message to send to the System.Diagnostics.Trace.Listeners collection.

  Assert(condition: bool,message: str,detailMessageFormat: str,*args: Array[object])

   Checks for a condition; if the condition is false,outputs two messages (simple and formatted) 

    and displays a message box that shows the call stack.

  

  

   condition: The conditional expression to evaluate. If the condition is true,the specified messages are not 

    sent and the message box is not displayed.

  

   message: The message to send to the System.Diagnostics.Trace.Listeners collection.

   detailMessageFormat: The composite format string (see Remarks) to send to the System.Diagnostics.Trace.Listeners 

    collection. This message contains text intermixed with zero or more format items,which 

    correspond to objects in the args array.

  

   args: An object array that contains zero or more objects to format.

  Assert(condition: bool)

   Checks for a condition; if the condition is false,displays a message box that shows the call 

    stack.

  

  

   condition: The conditional expression to evaluate. If the condition is true,a failure message is not sent 

    and the message box is not displayed.

  

  Assert(condition: bool,message: str)

   Checks for a condition; if the condition is false,outputs a specified message and displays a 

    message box that shows the call stack.

  

  

   condition: The conditional expression to evaluate. If the condition is true,the specified message is not 

    sent and the message box is not displayed.

  

   message: The message to send to the System.Diagnostics.Trace.Listeners collection.
  """
  pass
 @staticmethod
 def Close():
  """
  Close()

   Flushes the output buffer and then calls the Close method on each of the 

    System.Diagnostics.Debug.Listeners.
  """
  pass
 @staticmethod
 def Fail(message,detailMessage=None):
  """
  Fail(message: str,detailMessage: str)

   Emits an error message and a detailed error message.

  

   message: A message to emit.

   detailMessage: A detailed message to emit.

  Fail(message: str)

   Emits the specified error message.

  

   message: A message to emit.
  """
  pass
 @staticmethod
 def Flush():
  """
  Flush()

   Flushes the output buffer and causes buffered data to write to the 

    System.Diagnostics.Debug.Listeners collection.
  """
  pass
 @staticmethod
 def Indent():
  """
  Indent()

   Increases the current System.Diagnostics.Debug.IndentLevel by one.
  """
  pass
 @staticmethod
 def Print(*__args):
  """
  Print(format: str,*args: Array[object])

   Writes a formatted string followed by a line terminator to the trace listeners in the 

    System.Diagnostics.Debug.Listeners collection.

  

  

   format: A composite format string (see Remarks) that contains text intermixed with zero or more format 

    items,which correspond to objects in the args array.

  

   args: An object array containing zero or more objects to format.

  Print(message: str)

   Writes a message followed by a line terminator to the trace listeners in the 

    System.Diagnostics.Debug.Listeners collection.

  

  

   message: The message to write.
  """
  pass
 @staticmethod
 def Unindent():
  """
  Unindent()

   Decreases the current System.Diagnostics.Debug.IndentLevel by one.
  """
  pass
 @staticmethod
 def Write(*__args):
  """
  Write(message: str,category: str)

   Writes a category name and message to the trace listeners in the 

    System.Diagnostics.Debug.Listeners collection.

  

  

   message: A message to write.

   category: A category name used to organize the output.

  Write(value: object,category: str)

   Writes a category name and the value of the object's System.Object.ToString method to the trace 

    listeners in the System.Diagnostics.Debug.Listeners collection.

  

  

   value: An object whose name is sent to the System.Diagnostics.Debug.Listeners.

   category: A category name used to organize the output.

  Write(message: str)

   Writes a message to the trace listeners in the System.Diagnostics.Debug.Listeners collection.

  

   message: A message to write.

  Write(value: object)

   Writes the value of the object's System.Object.ToString method to the trace listeners in the 

    System.Diagnostics.Debug.Listeners collection.

  

  

   value: An object whose name is sent to the System.Diagnostics.Debug.Listeners.
  """
  pass
 @staticmethod
 def WriteIf(condition,*__args):
  """
  WriteIf(condition: bool,message: str,category: str)

   Writes a category name and message to the trace listeners in the 

    System.Diagnostics.Debug.Listeners collection if a condition is true.

  

  

   condition: The conditional expression to evaluate. If the condition is true,the category name and message 

    are written to the trace listeners in the collection.

  

   message: A message to write.

   category: A category name used to organize the output.

  WriteIf(condition: bool,value: object,category: str)

   Writes a category name and the value of the object's System.Object.ToString method to the trace 

    listeners in the System.Diagnostics.Debug.Listeners collection if a condition is true.

  

  

   condition: The conditional expression to evaluate. If the condition is true,the category name and value 

    are written to the trace listeners in the collection.

  

   value: An object whose name is sent to the System.Diagnostics.Debug.Listeners.

   category: A category name used to organize the output.

  WriteIf(condition: bool,message: str)

   Writes a message to the trace listeners in the System.Diagnostics.Debug.Listeners collection if 

    a condition is true.

  

  

   condition: The conditional expression to evaluate. If the condition is true,the message is written to the 

    trace listeners in the collection.

  

   message: A message to write.

  WriteIf(condition: bool,value: object)

   Writes the value of the object's System.Object.ToString method to the trace listeners in the 

    System.Diagnostics.Debug.Listeners collection if a condition is true.

  

  

   condition: The conditional expression to evaluate. If the condition is true,the value is written to the 

    trace listeners in the collection.

  

   value: An object whose name is sent to the System.Diagnostics.Debug.Listeners.
  """
  pass
 @staticmethod
 def WriteLine(*__args):
  """
  WriteLine(value: object,category: str)

   Writes a category name and the value of the object's System.Object.ToString method to the trace 

    listeners in the System.Diagnostics.Debug.Listeners collection.

  

  

   value: An object whose name is sent to the System.Diagnostics.Debug.Listeners.

   category: A category name used to organize the output.

  WriteLine(format: str,*args: Array[object])

   Writes a formatted message followed by a line terminator to the trace listeners in the 

    System.Diagnostics.Debug.Listeners collection.

  

  

   format: A composite format string (see Remarks) that contains text intermixed with zero or more format 

    items,which correspond to objects in the args array.

  

   args: An object array containing zero or more objects to format.

  WriteLine(message: str,category: str)

   Writes a category name and message to the trace listeners in the 

    System.Diagnostics.Debug.Listeners collection.

  

  

   message: A message to write.

   category: A category name used to organize the output.

  WriteLine(message: str)

   Writes a message followed by a line terminator to the trace listeners in the 

    System.Diagnostics.Debug.Listeners collection.

  

  

   message: A message to write.

  WriteLine(value: object)

   Writes the value of the object's System.Object.ToString method to the trace listeners in the 

    System.Diagnostics.Debug.Listeners collection.

  

  

   value: An object whose name is sent to the System.Diagnostics.Debug.Listeners.
  """
  pass
 @staticmethod
 def WriteLineIf(condition,*__args):
  """
  WriteLineIf(condition: bool,message: str,category: str)

   Writes a category name and message to the trace listeners in the 

    System.Diagnostics.Debug.Listeners collection if a condition is true.

  

  

   condition: true to cause a message to be written; otherwise,false.

   message: A message to write.

   category: A category name used to organize the output.

  WriteLineIf(condition: bool,value: object,category: str)

   Writes a category name and the value of the object's System.Object.ToString method to the trace 

    listeners in the System.Diagnostics.Debug.Listeners collection if a condition is true.

  

  

   condition: The conditional expression to evaluate. If the condition is true,the category name and value 

    are written to the trace listeners in the collection.

  

   value: An object whose name is sent to the System.Diagnostics.Debug.Listeners.

   category: A category name used to organize the output.

  WriteLineIf(condition: bool,message: str)

   Writes a message to the trace listeners in the System.Diagnostics.Debug.Listeners collection if 

    a condition is true.

  

  

   condition: The conditional expression to evaluate. If the condition is true,the message is written to the 

    trace listeners in the collection.

  

   message: A message to write.

  WriteLineIf(condition: bool,value: object)

   Writes the value of the object's System.Object.ToString method to the trace listeners in the 

    System.Diagnostics.Debug.Listeners collection if a condition is true.

  

  

   condition: The conditional expression to evaluate. If the condition is true,the value is written to the 

    trace listeners in the collection.

  

   value: An object whose name is sent to the System.Diagnostics.Debug.Listeners.
  """
  pass
 AutoFlush=False
 IndentLevel=0
 IndentSize=4
 Listeners=None
 __all__=[
  'Assert',
  'Close',
  'Fail',
  'Flush',
  'Indent',
  'Print',
  'Unindent',
  'Write',
  'WriteIf',
  'WriteLine',
  'WriteLineIf',
 ]




class InterfaceTypeAttribute(Attribute,_Attribute):
 """
 Indicates whether a managed interface is dual,dispatch-only,or IUnknown -only when exposed to COM.

 

 InterfaceTypeAttribute(interfaceType: ComInterfaceType)

 InterfaceTypeAttribute(interfaceType: Int16)
 """
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,interfaceType):
  """
  __new__(cls: type,interfaceType: ComInterfaceType)

  __new__(cls: type,interfaceType: Int16)
  """
  pass
 Value=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Runtime.InteropServices.ComInterfaceType value that describes how the interface should be exposed to COM.



Get: Value(self: InterfaceTypeAttribute) -> ComInterfaceType



"""





class LicenseManager(object):
 """ Provides properties and methods to add a license to a component and to manage a System.ComponentModel.LicenseProvider. This class cannot be inherited. """
 @staticmethod
 def CreateWithContext(type,creationContext,args=None):
  """
  CreateWithContext(type: Type,creationContext: LicenseContext,args: Array[object]) -> object

  

   Creates an instance of the specified type with the specified arguments,given a context in which 

    you can use the licensed instance.

  

  

   type: A System.Type that represents the type to create.

   creationContext: A System.ComponentModel.LicenseContext that specifies when you can use the licensed instance.

   args: An array of type System.Object that represents the arguments for the type.

   Returns: An instance of the specified type with the given array of arguments.

  CreateWithContext(type: Type,creationContext: LicenseContext) -> object

  

   Creates an instance of the specified type,given a context in which you can use the licensed 

    instance.

  

  

   type: A System.Type that represents the type to create.

   creationContext: A System.ComponentModel.LicenseContext that specifies when you can use the licensed instance.

   Returns: An instance of the specified type.
  """
  pass
 @staticmethod
 def IsLicensed(type):
  """
  IsLicensed(type: Type) -> bool

  

   Returns whether the given type has a valid license.

  

   type: The System.Type to find a valid license for.

   Returns: true if the given type is licensed; otherwise,false.
  """
  pass
 @staticmethod
 def IsValid(type,instance=None,license=None):
  """
  IsValid(type: Type,instance: object) -> (bool,License)

  

   Determines whether a valid license can be granted for the specified instance of the type. This 

    method creates a valid System.ComponentModel.License.

  

  

   type: A System.Type that represents the type of object that requests the license.

   instance: An object of the specified type or a type derived from the specified type.

   Returns: true if a valid System.ComponentModel.License can be granted; otherwise,false.

  IsValid(type: Type) -> bool

  

   Determines whether a valid license can be granted for the specified type.

  

   type: A System.Type that represents the type of object that requests the System.ComponentModel.License.

   Returns: true if a valid license can be granted; otherwise,false.
  """
  pass
 @staticmethod
 def LockContext(contextUser):
  """
  LockContext(contextUser: object)

   Prevents changes being made to the current System.ComponentModel.LicenseContext of the given 

    object.

  

  

   contextUser: The object whose current context you want to lock.
  """
  pass
 @staticmethod
 def UnlockContext(contextUser):
  """
  UnlockContext(contextUser: object)

   Allows changes to be made to the current System.ComponentModel.LicenseContext of the given 

    object.

  

  

   contextUser: The object whose current context you want to unlock.
  """
  pass
 @staticmethod
 def Validate(type,instance=None):
  """
  Validate(type: Type,instance: object) -> License

  

   Determines whether a license can be granted for the instance of the specified type.

  

   type: A System.Type that represents the type of object that requests the license.

   instance: An System.Object of the specified type or a type derived from the specified type.

   Returns: A valid System.ComponentModel.License.

  Validate(type: Type)

   Determines whether a license can be granted for the specified type.

  

   type: A System.Type that represents the type of object that requests the license.
  """
  pass
 CurrentContext=None
 UsageMode=None




class BindingManagerDataErrorEventArgs(EventArgs):
 """
 Provides data for the System.Windows.Forms.BindingManagerBase.DataError event.

 

 BindingManagerDataErrorEventArgs(exception: Exception)
 """
 @staticmethod
 def __new__(self,exception):
  """ __new__(cls: type,exception: Exception) """
  pass
 Exception=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Exception caught in the binding process that caused the System.Windows.Forms.BindingManagerBase.DataError event to be raised.



Get: Exception(self: BindingManagerDataErrorEventArgs) -> Exception



"""





class WebRequestMethods(object):
 """ Container class for System.Net.WebRequestMethods.Ftp,System.Net.WebRequestMethods.File,and System.Net.WebRequestMethods.Http classes. This class cannot be inherited """
 File=None
 Ftp=None
 Http=None
 __all__=[
  'File',
  'Ftp',
  'Http',
 ]




class PreviewKeyDownEventArgs(EventArgs):
 """
 Provides data for the System.Windows.Forms.Control.PreviewKeyDown event.

 

 PreviewKeyDownEventArgs(keyData: Keys)
 """
 @staticmethod
 def __new__(self,keyData):
  """ __new__(cls: type,keyData: Keys) """
  pass
 Alt=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the ALT key was pressed.



Get: Alt(self: PreviewKeyDownEventArgs) -> bool



"""

 Control=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the CTRL key was pressed.



Get: Control(self: PreviewKeyDownEventArgs) -> bool



"""

 IsInputKey=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether a key is a regular input key.



Get: IsInputKey(self: PreviewKeyDownEventArgs) -> bool



Set: IsInputKey(self: PreviewKeyDownEventArgs)=value

"""

 KeyCode=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the keyboard code for a System.Windows.Forms.Control.KeyDown or System.Windows.Forms.Control.KeyUp event.



Get: KeyCode(self: PreviewKeyDownEventArgs) -> Keys



"""

 KeyData=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the key data for a System.Windows.Forms.Control.KeyDown or System.Windows.Forms.Control.KeyUp event.



Get: KeyData(self: PreviewKeyDownEventArgs) -> Keys



"""

 KeyValue=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the keyboard value for a System.Windows.Forms.Control.KeyDown or System.Windows.Forms.Control.KeyUp event.



Get: KeyValue(self: PreviewKeyDownEventArgs) -> int



"""

 Modifiers=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the modifier flags for a System.Windows.Forms.Control.KeyDown or System.Windows.Forms.Control.KeyUp event.



Get: Modifiers(self: PreviewKeyDownEventArgs) -> Keys



"""

 Shift=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the SHIFT key was pressed.



Get: Shift(self: PreviewKeyDownEventArgs) -> bool



"""





"""Utility functions for creating data files within pyRevit environment.

Most times, scripts need to save some data to share between different scripts
that work on a similar topic or between script executions. This module provides
the necessary and consistent mechanism for creating and maintaining such files.

Examples:
    ```python
    from pyrevit.coreutils import appdata
    appdata.list_data_files()
    ```
"""

import os
import os.path as op
import re

import pyrevit
from pyrevit import EXEC_PARAMS
from pyrevit import coreutils
from pyrevit.coreutils import logger
from pyrevit.labs import TargetApps


#pylint: disable=W0703,C0302
mlogger = logger.get_logger(__name__)  #pylint: disable=C0103


TEMP_FILE_EXT = 'tmp'


def _remove_app_file(file_path):
    try:
        os.remove(file_path)
    except Exception as osremove_err:
        mlogger.debug('Error file cleanup on: %s | %s', file_path, osremove_err)


def _list_app_folders():
    app_folders = []
    for appdata_entry in os.listdir(pyrevit.PYREVIT_APP_DIR):
        if re.match(pattern=r'^\d{4}$', string=appdata_entry):
            app_folder = op.join(pyrevit.PYREVIT_APP_DIR, appdata_entry)
            if op.isdir(app_folder):
                app_folders.append(app_folder)
    return app_folders


def _list_app_files(prefix, file_ext, universal=False):
    requested_files = []

    if universal:
        appdata_folder = pyrevit.PYREVIT_APP_DIR
    else:
        appdata_folder = pyrevit.PYREVIT_VERSION_APP_DIR

    for appdata_file in os.listdir(appdata_folder):
        if appdata_file.startswith(prefix) and appdata_file.endswith(file_ext):
            requested_files.append(op.join(appdata_folder, appdata_file))

    return requested_files


def _get_app_file(file_id, file_ext,
                  filename_only=False, stamped=False, universal=False):
    appdata_folder = pyrevit.PYREVIT_VERSION_APP_DIR
    file_prefix = pyrevit.PYREVIT_FILE_PREFIX

    if stamped:
        file_prefix = pyrevit.PYREVIT_FILE_PREFIX_STAMPED
    elif universal:
        appdata_folder = pyrevit.PYREVIT_APP_DIR
        file_prefix = pyrevit.PYREVIT_FILE_PREFIX_UNIVERSAL

    full_filename = '{}{}.{}'.format(file_prefix, file_id, file_ext)

    if filename_only:
        return full_filename
    else:
        return op.join(
            appdata_folder,
            coreutils.cleanup_filename(full_filename)
            )


def _match_file(file_name):
    match = re.match(pattern=pyrevit.PYREVIT_FILE_PREFIX_STAMPED_USER_REGEX,
                     string=file_name)
    if match:
        return match.groupdict()

    # e.g. pyRevit_2018_14422_
    match = re.match(pattern=pyrevit.PYREVIT_FILE_PREFIX_STAMPED_REGEX,
                     string=file_name)
    if match:
        return match.groupdict()

    # e.g. pyRevit_2018_pyrevitlabs_
    match = re.match(pattern=pyrevit.PYREVIT_FILE_PREFIX_USER_REGEX,
                     string=file_name)
    if match:
        return match.groupdict()

    # e.g. pyRevit_2018_
    match = re.match(pattern=pyrevit.PYREVIT_FILE_PREFIX_REGEX,
                     string=file_name)
    if match:
        return match.groupdict()

    # e.g. pyRevit_pyrevitlabs_
    match = re.match(pattern=pyrevit.PYREVIT_FILE_PREFIX_UNIVERSAL_USER_REGEX,
                     string=file_name)
    if match:
        return match.groupdict()

    # e.g. pyRevit_
    match = re.match(pattern=pyrevit.PYREVIT_FILE_PREFIX_UNIVERSAL_REGEX,
                     string=file_name)
    if match:
        return match.groupdict()

    return {}


def get_universal_data_file(file_id, file_ext, name_only=False):
    """Get path to file that is shared between all host versions.

    These data files are not cleaned up at Revit restart.
    e.g pyrevit_pyrevitlabs_file_id.file_ext

    Args:
        file_id (str): Unique identifier for the file
        file_ext (str): File extension
        name_only (bool): If true, function returns file name only

    Returns:
        (str): File name or full file path (depending on name_only)
    """
    return _get_app_file(file_id, file_ext,
                         filename_only=name_only, universal=True)


def get_data_file(file_id, file_ext, name_only=False):
    """Get path to file that will not be cleaned up at Revit load.

    e.g pyrevit_2016_pyrevitlabs_file_id.file_ext

    Args:
        file_id (str): Unique identifier for the file
        file_ext (str): File extension
        name_only (bool): If true, function returns file name only

    Returns:
        (str): File name or full file path (depending on name_only)
    """
    return _get_app_file(file_id, file_ext, filename_only=name_only)


def get_instance_data_file(file_id, file_ext=TEMP_FILE_EXT, name_only=False):
    """Get path to file that should be used by current instance only.

    These data files will be cleaned up at Revit restart.
    e.g pyrevit_2016_pyrevitlabs_2353_file_id.file_ext

    Args:
        file_id (str): Unique identifier for the file
        file_ext (str): File extension
        name_only (bool): If true, function returns file name only

    Returns:
        (str): File name or full file path (depending on name_only)
    """
    return _get_app_file(file_id, file_ext,
                         filename_only=name_only, stamped=True)


def is_pyrevit_data_file(file_name):
    """Check if given file is a pyRevit data file.

    Args:
        file_name (str): file name

    Returns:
        (bool): True if file is a pyRevit data file
    """
    return pyrevit.PYREVIT_FILE_PREFIX in file_name


def is_file_available(file_name, file_ext, universal=False):
    """Check if given file is available within appdata directory.

    Args:
        file_name (str): file name
        file_ext (str): file extension
        universal (bool): Check against universal data files

    Returns:
        (str | bool): file path if file is available
    """
    if universal:
        full_filename = op.join(
            pyrevit.PYREVIT_APP_DIR,
            coreutils.make_canonical_name(file_name, file_ext))
    else:
        full_filename = op.join(
            pyrevit.PYREVIT_VERSION_APP_DIR,
            coreutils.make_canonical_name(file_name, file_ext))
    if op.exists(full_filename):
        return full_filename
    else:
        return False


def is_data_file_available(file_id, file_ext):
    """Check if given file is available within appdata directory.

    Args:
        file_id (str): data file id
        file_ext (str): file extension

    Returns:
        (str): file path if file is available
    """
    full_filename = _get_app_file(file_id, file_ext)
    if op.exists(full_filename):
        return full_filename
    else:
        return False


def list_data_files(file_ext, universal=False):
    """List all data files with given extension.

    Args:
        file_ext (str): file extension
        universal (bool): Check against universal data files

    Returns:
        (list[str]): list of files
    """
    return _list_app_files(
        pyrevit.PYREVIT_FILE_PREFIX,
        file_ext,
        universal=universal
        )


def list_instance_data_files(file_ext):
    """List all data files associated with current session.

    Args:
        file_ext (str): data files with this extension will be listed only.

    Returns:
        (list[str]): list of data files

    """
    return _list_app_files(pyrevit.PYREVIT_FILE_PREFIX_STAMPED, file_ext)


def find_data_files(file_ext):
    """Find data files in all data files directories.

    Args:
        file_ext (str): data files with this extension will be listed only

    Returns:
        (list[str]): list of files
    """
    all_datafiles = set()
    for app_folder in _list_app_folders():
        for appdata_file in os.listdir(app_folder):
            file_naming_dict = _match_file(
                op.basename(appdata_file)
            )
            if file_naming_dict \
                    and file_naming_dict['fname'].endswith(file_ext):
                all_datafiles.add(
                    op.join(app_folder, appdata_file)
                    )
    return all_datafiles


def find_instance_data_files(file_ext, instance_id):
    """Find instance data files in all data files directories.

    Args:
        file_ext (str): data files with this extension will be listed only
        instance_id (int): list data files for this instance id only

    Returns:
        (list[str]): list of files
    """
    # instance files names are like pyRevit_2018_14422_
    instance_files = set()
    for appdata_file in find_data_files(file_ext):
        file_naming_dict = _match_file(
            op.basename(appdata_file)
        )
        if 'pid' in file_naming_dict:
            try:
                pid = int(file_naming_dict['pid'])
                if instance_id == pid:
                    instance_files.add(appdata_file)
            except Exception:
                pass
    return instance_files


def garbage_data_file(file_path):
    """Mark and remove the given appdata file.

    Current implementation removes the file immediately.

    Args:
        file_path (str): path to the target file
    """
    _remove_app_file(file_path)


def cleanup_appdata_folder():
    """Cleanup appdata folder of all temporary appdata files."""
    if EXEC_PARAMS.first_load:
        hostapp_pids = \
            [x.ProcessId
             for x in TargetApps.Revit.RevitController.ListRunningRevits()]
        for appdata_file in os.listdir(pyrevit.PYREVIT_VERSION_APP_DIR):
            file_naming_dict = _match_file(appdata_file)
            if 'pid' in file_naming_dict:
                try:
                    pid = int(file_naming_dict['pid'])
                    if pid not in hostapp_pids:
                        _remove_app_file(
                            op.join(pyrevit.PYREVIT_VERSION_APP_DIR,
                                    appdata_file)
                            )
                except Exception:
                    pass



class GroupBoxRenderer(object):
 """ Provides methods used to render a group box control with or without visual styles. This class cannot be inherited. """
 @staticmethod
 def DrawGroupBox(g,bounds,*__args):
  """
  DrawGroupBox(g: Graphics,bounds: Rectangle,groupBoxText: str,font: Font,flags: TextFormatFlags,state: GroupBoxState)

   Draws a group box control in the specified state and bounds,with the specified text,font,and 

    text formatting.

  

  

   g: The System.Drawing.Graphics used to draw the group box.

   bounds: The System.Drawing.Rectangle that specifies the bounds of the group box.

   groupBoxText: The System.String to draw with the group box.

   font: The System.Drawing.Font to apply to groupBoxText.

   flags: A bitwise combination of the System.Windows.Forms.TextFormatFlags values.

   state: One of the System.Windows.Forms.VisualStyles.GroupBoxState values that specifies the visual 

    state of the group box.

  

  DrawGroupBox(g: Graphics,bounds: Rectangle,groupBoxText: str,font: Font,textColor: Color,flags: TextFormatFlags,state: GroupBoxState)

   Draws a group box control in the specified state and bounds,with the specified text,font,

    color,and text formatting.

  

  

   g: The System.Drawing.Graphics used to draw the group box.

   bounds: The System.Drawing.Rectangle that specifies the bounds of the group box.

   groupBoxText: The System.String to draw with the group box.

   font: The System.Drawing.Font to apply to groupBoxText.

   textColor: The System.Drawing.Color to apply to groupBoxText.

   flags: A bitwise combination of the System.Windows.Forms.TextFormatFlags values.

   state: One of the System.Windows.Forms.VisualStyles.GroupBoxState values that specifies the visual 

    state of the group box.

  

  DrawGroupBox(g: Graphics,bounds: Rectangle,groupBoxText: str,font: Font,textColor: Color,state: GroupBoxState)

   Draws a group box control in the specified state and bounds,with the specified text,font,and 

    color.

  

  

   g: The System.Drawing.Graphics used to draw the group box.

   bounds: The System.Drawing.Rectangle that specifies the bounds of the group box.

   groupBoxText: The System.String to draw with the group box.

   font: The System.Drawing.Font to apply to groupBoxText.

   textColor: The System.Drawing.Color to apply to groupBoxText.

   state: One of the System.Windows.Forms.VisualStyles.GroupBoxState values that specifies the visual 

    state of the group box.

  

  DrawGroupBox(g: Graphics,bounds: Rectangle,state: GroupBoxState)

   Draws a group box control in the specified state and bounds.

  

   g: The System.Drawing.Graphics used to draw the group box.

   bounds: The System.Drawing.Rectangle that specifies the bounds of the group box.

   state: One of the System.Windows.Forms.VisualStyles.GroupBoxState values that specifies the visual 

    state of the group box.

  

  DrawGroupBox(g: Graphics,bounds: Rectangle,groupBoxText: str,font: Font,state: GroupBoxState)

   Draws a group box control in the specified state and bounds,with the specified text and font.

  

   g: The System.Drawing.Graphics used to draw the group box.

   bounds: The System.Drawing.Rectangle that specifies the bounds of the group box.

   groupBoxText: The System.String to draw with the group box.

   font: The System.Drawing.Font to apply to groupBoxText.

   state: One of the System.Windows.Forms.VisualStyles.GroupBoxState values that specifies the visual 

    state of the group box.
  """
  pass
 @staticmethod
 def DrawParentBackground(g,bounds,childControl):
  """
  DrawParentBackground(g: Graphics,bounds: Rectangle,childControl: Control)

   Draws the background of a control's parent in the specified area.

  

   g: The System.Drawing.Graphics used to draw the background of the parent of childControl.

   bounds: The System.Drawing.Rectangle in which to draw the parent control's background. This rectangle 

    

   childControl: The control whose parent's background will be drawn.
  """
  pass
 @staticmethod
 def IsBackgroundPartiallyTransparent(state):
  """
  IsBackgroundPartiallyTransparent(state: GroupBoxState) -> bool

  

   Indicates whether the background of the group box has any semitransparent or alpha-blended 

    pieces.

  

  

   state: One of the System.Windows.Forms.VisualStyles.GroupBoxState values that specifies the visual 

    state of the group box.

  

   Returns: true if the background of the group box has semitransparent or alpha-blended pieces; otherwise,

    false.
  """
  pass
 RenderMatchingApplicationState=True




class AccessibleStates(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies values representing possible states for an accessible object.

 

 enum (flags) AccessibleStates,values: AlertHigh (268435456),AlertLow (67108864),AlertMedium (134217728),Animated (16384),Busy (2048),Checked (16),Collapsed (1024),Default (256),Expanded (512),ExtSelectable (33554432),Floating (4096),Focusable (1048576),Focused (4),HasPopup (1073741824),HotTracked (128),Indeterminate (32),Invisible (32768),Linked (4194304),Marqueed (8192),Mixed (32),Moveable (262144),MultiSelectable (16777216),None (0),Offscreen (65536),Pressed (8),Protected (536870912),ReadOnly (64),Selectable (2097152),Selected (2),SelfVoicing (524288),Sizeable (131072),Traversed (8388608),Unavailable (1),Valid (1073741823)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 AlertHigh=None
 AlertLow=None
 AlertMedium=None
 Animated=None
 Busy=None
 Checked=None
 Collapsed=None
 Default=None
 Expanded=None
 ExtSelectable=None
 Floating=None
 Focusable=None
 Focused=None
 HasPopup=None
 HotTracked=None
 Indeterminate=None
 Invisible=None
 Linked=None
 Marqueed=None
 Mixed=None
 Moveable=None
 MultiSelectable=None
 None=None
 Offscreen=None
 Pressed=None
 Protected=None
 ReadOnly=None
 Selectable=None
 Selected=None
 SelfVoicing=None
 Sizeable=None
 Traversed=None
 Unavailable=None
 Valid=None
 value__=None

